<?php
/*
 * All Back-End Helper Functions for Ceremony Theme
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

/* Validate px entered in field */
if( ! function_exists( 'ceremony_check_px' ) ) {
  function ceremony_check_px( $num ) {
    return ( is_numeric( $num ) ) ? $num . 'px' : $num;
  }
}

/* Escape Strings */
if( ! function_exists( 'ceremony_vt_esc_string' ) ) {
  function ceremony_vt_esc_string( $num ) {
    return preg_replace('/\D/', '', $num);
  }
}

/* Escape Numbers */
if( ! function_exists( 'ceremony_vt_esc_number' ) ) {
  function ceremony_vt_esc_number( $num ) {
    return preg_replace('/[^a-zA-Z]/', '', $num);
  }
}

/* Inline Style */
global $all_inline_styles;
$all_inline_styles = array();
if( ! function_exists( 'ceremony_add_inline_style' ) ) {
  function ceremony_add_inline_style( $style ) {
    global $all_inline_styles;
    array_push( $all_inline_styles, $style );
  }
}

/* Support WordPress uploader to following file extensions */
if( ! function_exists( 'ceremony_vt_upload_mimes' ) ) {
  function ceremony_vt_upload_mimes( $mimes ) {

    $mimes['ttf']   = 'font/ttf';
    $mimes['eot']   = 'font/eot';
    $mimes['woff']  = 'font/woff';
    $mimes['otf']   = 'font/otf';

    return $mimes;

  }
  add_filter( 'upload_mimes', 'ceremony_vt_upload_mimes' );
}

/* HEX to RGB */
if( ! function_exists( 'ceremony_vt_hex2rgb' ) ) {
  function ceremony_vt_hex2rgb( $hexcolor, $opacity = 1 ) {

    if( preg_match( '/^#[a-fA-F0-9]{6}|#[a-fA-F0-9]{3}$/i', $hexcolor ) ) {

      $hex    = str_replace( '#', '', $hexcolor );

      if( strlen( $hex ) == 3 ) {
        $r    = hexdec( substr( $hex, 0, 1 ) . substr( $hex, 0, 1 ) );
        $g    = hexdec( substr( $hex, 1, 1 ) . substr( $hex, 1, 1 ) );
        $b    = hexdec( substr( $hex, 2, 1 ) . substr( $hex, 2, 1 ) );
      } else {
        $r    = hexdec( substr( $hex, 0, 2 ) );
        $g    = hexdec( substr( $hex, 2, 2 ) );
        $b    = hexdec( substr( $hex, 4, 2 ) );
      }

      return ( isset( $opacity ) && $opacity != 1 ) ? 'rgba('. $r .', '. $g .', '. $b .', '. $opacity .')' : ' ' . $hexcolor;

    } else {

      return $hexcolor;

    }

  }
}

/* Yoast Plugin Metabox Low */
if( ! function_exists( 'ceremony_vt_yoast_metabox' ) ) {
  function ceremony_vt_yoast_metabox() {
    return 'low';
  }
  add_filter( 'wpseo_metabox_prio', 'ceremony_vt_yoast_metabox' );
}

if( ! function_exists( 'ceremony_is_post_type' ) ) {
  function ceremony_is_post_type($type){
    global $wp_query;
    if($type == get_post_type($wp_query->post->ID)) return true;
    return false;
  }
}

/**
 * If WooCommerce Plugin Activated
 */
if ( ! function_exists( 'ceremony_is_woocommerce_activated' ) ) {
  function ceremony_is_woocommerce_activated() {
    if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
  }
}

/**
 * If is WooCommerce Shop
 */
if ( ! function_exists( 'ceremony_is_woocommerce_shop' ) ) {
  function ceremony_is_woocommerce_shop() {
    if ( ceremony_is_woocommerce_activated() && is_shop() ) { return true; } else { return false; }
  }
}

/**
 * If is WPML is active
 */
if ( ! function_exists( 'ceremony_is_wpml_activated' ) ) {
  function ceremony_is_wpml_activated() {
    if ( class_exists( 'SitePress' ) ) { return true; } else { return false; }
  }
}

/**
 * Remove Rev Slider Metabox
 */
if ( is_admin() ) {
  if( ! function_exists( 'ceremony_remove_rev_slider_meta_boxes' ) ) {
    function ceremony_remove_rev_slider_meta_boxes() {
      remove_meta_box( 'mymetabox_revslider_0', 'page', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'post', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'friends', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'testimonial', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'gallery', 'normal' );
    }
    add_action( 'do_meta_boxes', 'ceremony_remove_rev_slider_meta_boxes' );
  }
}

/**
 * Custom Font Family
 */
if ( ! function_exists( 'ceremony_custom_font_load' ) ) {
  function ceremony_custom_font_load() {

    $font_family       = cs_get_option( 'font_family' );

    ob_start();

    if( ! empty( $font_family ) ) {

      foreach ( $font_family as $font ) {
        echo '@font-face{';

        echo 'font-family: "'. $font['name'] .'";';

        if( empty( $font['css'] ) ) {
          echo 'font-style: normal;';
          echo 'font-weight: normal;';
        } else {
          echo $font['css']; // CeremonyWP
        }

        echo ( ! empty( $font['ttf']  ) ) ? 'src: url('. esc_url($font['ttf']).');' : '';
        echo ( ! empty( $font['eot']  ) ) ? 'src: url('. esc_url($font['eot']).');' : '';
        echo ( ! empty( $font['woff'] ) ) ? 'src: url('. esc_url($font['woff']) .');' : '';
        echo ( ! empty( $font['otf']  ) ) ? 'src: url('. esc_url($font['otf']).');' : '';

        echo '}';
      }

    }

    // Typography
    $output = ob_get_clean();
    return $output;
  }
}

/* Custom Styles */
if( ! function_exists( 'ceremony_vt_custom_css' ) ) {
  function ceremony_vt_custom_css() {
    wp_enqueue_style('ceremony-default-style', get_template_directory_uri() . '/style.css');
    $output  = ceremony_custom_font_load();
    if( function_exists( 'ceremony_compress_css_lines' ) ) {
      $custom_css = ceremony_compress_css_lines( $output );
      wp_add_inline_style( 'ceremony-default-style', $custom_css );
    }
  }
}

// Media custom options
function ceremony_gallery_attachment_field_credit( $form_fields, $post ) {
  $form_fields['image-media-link'] = array(
    'label' => esc_html__('Large Image URL', 'ceremony'),
    'input' => 'text',
    'value' => get_post_meta( $post->ID, '_image_media_link', true ),
    'helps' =>  esc_html__('Add large image URL', 'ceremony'),
  );

  return $form_fields;
}
add_filter( 'attachment_fields_to_edit', 'ceremony_gallery_attachment_field_credit', 10, 3 );

// Adding extra feature image for aligning content in one div in day view
if ( ! function_exists( 'ceremony_add_featured_image' ) ) {
  function ceremony_add_featured_image() {
    echo '<div class="list-featured-image">';
    echo tribe_event_featured_image( null, 'medium' );
    echo '</div>';
  }
  add_action('tribe_events_before_the_event_title','ceremony_add_featured_image');
}

// Adding extra feature image for aligning content in one div in day view
if ( ! function_exists( 'ceremony_add_event_organizer' ) ) {
  function ceremony_add_event_organizer() {
    $organizer_ids = tribe_get_organizer_ids();
    $multiple = count( $organizer_ids ) > 1;

    if ( tribe_has_organizer() ) {
      echo '<div class="event-author"><h3 class="event-author-title">'.tribe_get_organizer_label( ! $multiple ).'</h3>';
      foreach ( $organizer_ids as $organizer ) {
        $phone = tribe_get_organizer_phone($organizer);
        $email = tribe_get_organizer_email($organizer);
        $website = tribe_get_organizer_website_link($organizer);
        $start_date = tribe_get_start_date( null, false );
        if ( ! $organizer ) {
          continue;
        }
        $size = 'medium';
        $link = false;
        ?>
        <div class="event-author-item col-md-6">
          <div class="crmny-image"><?php echo tribe_event_featured_image( $organizer, $size, $link ); ?></div>
          <div class="event-author-info">
          <?php
            $content_post = get_post(tribe_get_organizer_ID($organizer));
            $content = $content_post->post_content;
            $content = apply_filters('the_content', $content);
            $content = str_replace(']]>', ']]&gt;', $content);
          ?>
            <h4 class="event-author-name"><?php echo tribe_get_organizer_link( $organizer ); ?></h4>
            <div class="event-author-timing">
              <p><span><?php esc_html_e( 'Event Time:', 'ceremony' ); ?></span>  <?php echo tribe_get_start_time().' - '.tribe_get_end_time(); ?></p>
              <p><span><?php esc_html_e( 'Event Place:', 'ceremony' ); ?></span>  <?php echo tribe_get_venue(); ?></p>
              <p><span><?php esc_html_e( 'Phone:', 'ceremony' ); ?></span>  <?php echo esc_html( $phone ); ?></p>
              <p><span><?php esc_html_e( 'Email:', 'ceremony' ) ?></span>  <?php echo esc_html( $email ); ?></p>
              <p><span><?php esc_html_e( 'Website:', 'ceremony' ) ?></span>  <?php echo $website; ?></p> <!-- CeremonyWP -->
            </div>
          </div>
        </div>
    <?php }
    echo '</div>';
    }
  }
  add_action('tribe_events_single_event_after_the_content','ceremony_add_event_organizer');
}

/**
 * Check if Codestar Framework is Active or Not!
 */
if ( ! function_exists( 'ceremony_framework_active' ) ) {
  function ceremony_framework_active() {
    return ( defined( 'CS_VERSION' ) ) ? true : false;
  }
}

// cs_get_option
if ( ! function_exists( 'cs_get_option' ) ) {
  function cs_get_option( $option_name = '', $default = '' ) {

    if (ceremony_framework_active()) {
      $options = apply_filters( 'cs_get_option', get_option( CS_OPTION ), $option_name, $default );
    } else {
      $options = '';
    }

    if( ! empty( $option_name ) && ! empty( $options[$option_name] ) ) {
      return $options[$option_name];
    } else {
      return ( ! empty( $default ) ) ? $default : null;
    }

  }
}

// cs_get_customize_option
if ( ! function_exists( 'cs_get_customize_option' ) ) {
  function cs_get_customize_option( $option_name = '', $default = '' ) {

    if (ceremony_framework_active()) {
      $options = apply_filters( 'cs_get_customize_option', get_option( CS_CUSTOMIZE ), $option_name, $default );
    } else {
      $options = '';
    }

    if( ! empty( $option_name ) && ! empty( $options[$option_name] ) ) {
      return $options[$option_name];
    } else {
      return ( ! empty( $default ) ) ? $default : null;
    }

  }
}
