<?php
/*
 * All Front-End Helper Functions
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

/* Exclude category from blog */
if( ! function_exists( 'ceremony_vt_excludeCat' ) ) {
  function ceremony_vt_excludeCat($query) {
  	if ( $query->is_home ) {
  		$exclude_cat_ids = cs_get_option('theme_exclude_categories');
  		if($exclude_cat_ids) {
  			foreach( $exclude_cat_ids as $exclude_cat_id ) {
  				$exclude_from_blog[] = '-'. $exclude_cat_id;
  			}
  			$query->set('cat', implode(',', $exclude_from_blog));
  		}
  	}
  	return $query;
  }
  add_filter('pre_get_posts', 'ceremony_vt_excludeCat');
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function ceremony_pingback_header() {
  if ( is_singular() && pings_open() ) {
    echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
  }
}
add_action( 'wp_head', 'ceremony_pingback_header' );

/* Include Default value for dropdown in contact form7*/
function ceremony_wpcf7_form_elements($html) {
    $text = 'Choose';
    $html = str_replace('---',  $text , $html);
    return $html;
}
add_filter('wpcf7_form_elements', 'ceremony_wpcf7_form_elements');

/* Excerpt Length */
class CeremonyExcerpt {

  // Default length (by WordPress)
  public static $length = 55;

  // Output: ceremony_excerpt('short');
  public static $types = array(
    'short' => 25,
    'regular' => 55,
    'long' => 100
  );

  /**
   * Sets the length for the excerpt,
   * then it adds the WP filter
   * And automatically calls the_excerpt();
   *
   * @param string $new_length
   * @return void
   * @author Baylor Rae'
   */
  public static function length($new_length = 55) {
    CeremonyExcerpt::$length = $new_length;
    add_filter('excerpt_length', 'CeremonyExcerpt::new_length');
    CeremonyExcerpt::output();
  }

  // Tells WP the new length
  public static function new_length() {
    if( isset(CeremonyExcerpt::$types[CeremonyExcerpt::$length]) )
      return CeremonyExcerpt::$types[CeremonyExcerpt::$length];
    else
      return CeremonyExcerpt::$length;
  }

  // Echoes out the excerpt
  public static function output() {
    the_excerpt();
  }

}

// Custom Excerpt Length
if( ! function_exists( 'ceremony_excerpt' ) ) {
  function ceremony_excerpt($length = 55) {
    CeremonyExcerpt::length($length);
  }
}

if ( ! function_exists( 'ceremony_new_excerpt_more' ) ) {
  function ceremony_new_excerpt_more( $more ) {
    return '...';
  }
  add_filter('excerpt_more', 'ceremony_new_excerpt_more');
}

/* Tag Cloud Widget - Remove Inline Font Size */
add_filter( 'widget_tag_cloud_args', 'ceremony_change_tag_cloud_font_sizes');

/**
 * Change the Tag Cloud's Font Sizes.
 *
 * @since 1.0.0
 *
 * @param array $args
 *
 * @return array
 */
function ceremony_change_tag_cloud_font_sizes( array $args ) {
  $args['smallest'] = '10';
  $args['largest'] = '10';

  return $args;
}

/* Password Form */
if( ! function_exists( 'ceremony_vt_password_form' ) ) {
  function ceremony_vt_password_form( $output ) {
    $output = str_replace( 'type="submit"', 'type="submit" class=""', $output );
    return $output;
  }
  add_filter('the_password_form' , 'ceremony_vt_password_form');
}

/* Maintenance Mode */
if( ! function_exists( 'ceremony_vt_maintenance_mode' ) ) {
  function ceremony_vt_maintenance_mode(){

    $maintenance_mode_page = cs_get_option( 'maintenance_mode_page' );
    $enable_maintenance_mode = cs_get_option( 'enable_maintenance_mode' );

    if ( isset($enable_maintenance_mode) && ! empty( $maintenance_mode_page ) && ! is_user_logged_in() ) {
      get_template_part('layouts/post/content', 'maintenance');
      exit;
    }

  }
  add_action( 'wp', 'ceremony_vt_maintenance_mode', 1 );
}

/* Maintenance Mode */
if( ! function_exists( 'ceremony_vt_maintenance_mode' ) ) {
  function ceremony_vt_maintenance_mode(){

    $maintenance_mode_page = cs_get_option( 'maintenance_mode_page' );
    $enable_maintenance_mode = cs_get_option( 'enable_maintenance_mode' );

    if ( isset($enable_maintenance_mode) && ! empty( $maintenance_mode_page ) && ! is_user_logged_in() ) {
      get_template_part('layouts/post/content', 'maintenance');
      exit;
    }

  }
  add_action( 'wp', 'ceremony_vt_maintenance_mode', 1 );
}

/* Widget Layouts */
if ( ! function_exists( 'ceremony_vt_footer_widgets' ) ) {
  function ceremony_vt_footer_widgets() {

    $output = '';
    $footer_widget_layout = cs_get_option('footer_widget_layout');

    if( $footer_widget_layout ) {

      switch ( $footer_widget_layout ) {
        case 1: $widget = array('piece' => 1, 'class' => 'col-md-12'); break;
        case 2: $widget = array('piece' => 2, 'class' => 'col-md-6'); break;
        case 3: $widget = array('piece' => 3, 'class' => 'col-md-4'); break;
        case 4: $widget = array('piece' => 4, 'class' => 'col-md-12 col-lg-3'); break;
        case 5: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 6: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 2); break;
        case 7: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 3); break;
        case 8: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 9: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 4); break;
        case 10: $widget = array('piece' => 4, 'class' => 'col-md-3', 'layout' => 'col-md-2', 'queue' => 2, 'layout_two' => 'col-md-4', 'queue_two' => 4); break;
        default : $widget = array('piece' => 4, 'class' => 'col-md-3'); break;
      }

      for( $i = 1; $i < $widget["piece"]+1; $i++ ) {
        if(isset( $widget["queue_two"] ) && $widget["queue_two"] == $i ){
          $widget_cls = ( isset( $widget["queue_two"] ) && $widget["queue_two"] == $i ) ? $widget["layout_two"] : '';
          $widget_class = '';
        } else {
          $widget_class = ( isset( $widget["queue"] ) && $widget["queue"] == $i ) ? $widget["layout"] : $widget["class"];
          $widget_cls = '';
        }
        $output .= '<div class="footer-widget '. $widget_class .' '.$widget_cls.'">';
        ob_start();
        if (is_active_sidebar('footer-'. $i)) {
          dynamic_sidebar( 'footer-'. $i );
        }
        $output .= ob_get_clean();
        $output .= '</div>';
      }
    }
    return $output;
  }
}

if( ! function_exists( 'ceremony_vt_top_bar' ) ) {
  function ceremony_vt_top_bar() {

    $out     = '';
    if ( ( cs_get_option( 'top_left' ) || cs_get_option( 'top_right' ) ) ) {
      $out .= '<div class="crmny-topbar"><div class="container"><div class="row">';
      $out .= ceremony_vt_top_bar_modules( 'left' );
      $out .= ceremony_vt_top_bar_modules( 'right' );
      $out .= '</div></div></div>';
    }
    return $out;
  }
}

/* WP Link Pages */
if ( ! function_exists( 'ceremony_wp_link_pages' ) ) {
  function ceremony_wp_link_pages() {
    $defaults = array(
      'before'           => '<div class="wp-link-pages">' . esc_html__( 'Pages:', 'ceremony' ),
      'after'            => '</div>',
      'link_before'      => '<span>',
      'link_after'       => '</span>',
      'next_or_number'   => 'number',
      'separator'        => ' ',
      'pagelink'         => '%',
      'echo'             => 1
    );
    wp_link_pages( $defaults );
  }
}

/* Author Info */
if ( ! function_exists( 'ceremony_author_info' ) ) {
  function ceremony_author_info() {

    if (get_the_author_meta( 'url' )) {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_the_author_meta( 'url' );
      $target = 'target="_blank"';
    } else {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $target = '';
    }

    // variables
    $author_text = cs_get_option('author_text');
    $author_text = $author_text ? $author_text : esc_html__( 'Author', 'ceremony' );
    $author_content = get_the_author_meta( 'description' );
if ($author_content) {
?>
<div class="crmny-author-info">
  <div class="author-avatar">
     <a href="<?php echo esc_url($website_url); ?>" <?php echo esc_attr($target); ?>>
        <?php echo get_avatar( get_the_author_meta( 'ID' ), 76 ); ?>
      </a>
  </div>
  <div class="author-content">
    <a href="<?php echo esc_url($author_url); ?>" class="author-name"><?php echo esc_html(get_the_author_meta('first_name')).' '.esc_html(get_the_author_meta('last_name')); ?></a>
    <p><?php echo esc_html(get_the_author_meta( 'description' )); ?></p>
    <div class="crmny-social rounded">
        <?php if (get_the_author_meta( 'twitter' )): ?><a href="<?php echo esc_url( get_the_author_meta( 'twitter' ) ); ?>" target="_blank"><i class="fa fa-twitter"></i></a>
        <?php endif;
        if (get_the_author_meta( 'facebook' )): ?><a href="<?php echo esc_url( get_the_author_meta( 'facebook' ) ); ?>" target="_blank"><i class="fa fa-facebook"></i></a>
        <?php endif;
        if (get_the_author_meta( 'pinterest' )): ?><a href="<?php echo esc_url( get_the_author_meta( 'pinterest' ) ); ?>" target="_blank"><i class="fa fa-pinterest"></i></a>
        <?php endif; ?>
    </div>
  </div>
</div>
<?php
} // if $author_content
  }
}

/* ==============================================
   Custom Comment Area Modification
=============================================== */
if ( ! function_exists( 'ceremony_comment_modification' ) ) {
  function ceremony_comment_modification($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);
    if ( 'div' == $args['style'] ) {
      $tag = 'div';
      $add_below = 'comment';
    } else {
      $tag = 'li';
      $add_below = 'div-comment';
    }
    $comment_class = empty( $args['has_children'] ) ? '' : 'parent';
  ?>

  <<?php echo esc_attr($tag); ?> <?php comment_class('item ' . $comment_class .' ' ); ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="comment-item">
    <?php endif; ?>
    <div class="comment-theme">
        <div class="comment-image">
          <?php if ( $args['avatar_size'] != 0 ) {
            echo get_avatar( $comment, 76 );
          } ?>
        </div>
    </div>
    <div class="comment-main-area">
      <div class="comment-wrapper">
        <div class="crmny-comments-meta">
          <h4><?php printf( '%s', get_comment_author() ); ?></h4>
          <span class="comments-date"><?php echo esc_html(get_comment_date('M d, Y')); esc_html_e(' at ','ceremony'); echo esc_html(get_comment_time()); ?></span>
        </div>
        <?php if ( $comment->comment_approved == '0' ) : ?>
        <em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'ceremony' ); ?></em>
        <?php endif; ?>
        <div class="comment-area">
          <?php comment_text(); ?>
        </div>
        <div class="comments-reply">
        <?php
          comment_reply_link( array_merge( $args, array(
          'reply_text' => '<span class="comment-reply-link"><i class="fa fa-reply-all" aria-hidden="true"></i>'. esc_html__('Reply','ceremony') .'</span>',
          'before' => '',
          'class'  => '',
          'depth' => $depth,
          'max_depth' => $args['max_depth']
          ) ) );
        ?>
        </div>
    </div>
    </div>
  <?php if ( 'div' != $args['style'] ) : ?>
  </div>
  <?php endif;
  }
}

/* Comments Form - Textarea next to Normal Fields */
if( ! function_exists( 'ceremony_move_comment_field' ) ) {
  add_filter( 'comment_form_fields', 'ceremony_move_comment_field' );
  function ceremony_move_comment_field( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
  }
}

/* Title Area */
if ( ! function_exists( 'ceremony_title_area' ) ) {
  function ceremony_title_area() {

    global $post, $wp_query;
    // Get post meta in all type of WP pages
    $ceremony_id    = ( isset( $post ) ) ? $post->ID : 0;
    $ceremony_id    = ( is_home() ) ? get_option( 'page_for_posts' ) : $ceremony_id;
    $ceremony_id    = ( ceremony_is_woocommerce_shop() ) ? wc_get_page_id( 'shop' ) : $ceremony_id;
    $ceremony_meta  = get_post_meta( $ceremony_id, 'page_type_metabox', true );
    if ($ceremony_meta && (!is_archive() || ceremony_is_woocommerce_shop())) {
      $custom_title = $ceremony_meta['page_custom_title'];
      if ($custom_title) {
        $custom_title = $custom_title;
      } else {
        $custom_title = '';
      }
    } else { $custom_title = ''; }

    /**
     * For strings with necessary HTML, use the following:
     * Note that I'm only including the actual allowed HTML for this specific string.
     * More info: https://codex.wordpress.org/Function_Reference/wp_kses
     */
    $allowed_title_area_tags = array(
        'a' => array(
          'href' => array(),
        ),
        'span' => array(
          'class' => array(),
        )
    );

    if( $custom_title && !is_search()) {
      echo esc_html($custom_title);
    } elseif ( is_home() ) {
      bloginfo('description');
    } elseif( is_singular('tribe_events') ) {
      echo esc_html(get_the_title($wp_query->post->ID));
    } elseif( is_singular('product') ) {
      $post_type = get_post_type_object( get_post_type($post) );
      echo esc_html($post_type->label);
    } elseif( is_singular('friends') ) {
      $post_type = get_post_type_object( get_post_type($post) );
      echo esc_html($post_type->label);
    } elseif( is_singular('gallery') ) {
      $post_type = get_post_type_object( get_post_type($post) );
      echo esc_html($post_type->label);
    } elseif ( is_search() ) {
      printf( esc_html__( 'Search Results for %s', 'ceremony' ), '<span>' . get_search_query() . '</span>' );
    } elseif ( is_category() || is_tax() ){
      single_cat_title();
    } elseif ( is_tag() ){
      single_tag_title(esc_html__('Posts Tagged: ', 'ceremony'));
    } elseif ( is_archive() ){
      if ( is_day() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'ceremony' ), $allowed_title_area_tags ), get_the_date());
      } elseif ( is_month() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'ceremony' ), $allowed_title_area_tags ), get_the_date( 'F, Y' ));
      } elseif ( is_year() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'ceremony' ), $allowed_title_area_tags ), get_the_date( 'Y' ));
      } elseif ( is_author() ) {
        printf( wp_kses( __( 'Posts by: <span>%s</span>', 'ceremony' ), $allowed_title_area_tags ), get_the_author_meta( 'display_name', $wp_query->post->post_author ));
      } elseif( ceremony_is_woocommerce_shop() ) {
        esc_html_e( 'Shop', 'ceremony' );
      } elseif(tribe_is_month()) {
        esc_html_e( 'Events', 'ceremony' );
      } elseif ( is_post_type_archive() ) {
        post_type_archive_title();
      } else {
        esc_html_e( 'Archives', 'ceremony' );
      }
    } elseif( is_404() ) {
      esc_html_e('404', 'ceremony');
    } else {
      the_title();
    }

  }
}

/* Single Gallery Pagination */
if ( ! function_exists( 'ceremony_single_gallery_navigation' ) ) {
  function ceremony_single_gallery_navigation() {
      $prev_post = get_previous_post();
      $next_post = get_next_post();
      $gallery_home_link = cs_get_option('gallery_home_link');
      $ceremony_prev_galry = cs_get_option('prev_gallery');
      $ceremony_next_galry = cs_get_option('next_gallery');
      $ceremony_prev_galry = ($ceremony_prev_galry) ? $ceremony_prev_galry : esc_html__('Previous', 'ceremony');
      $ceremony_next_galry = ($ceremony_next_galry) ? $ceremony_next_galry : esc_html__('Next', 'ceremony');
      ?>
      <div class="gallery-controls">
        <div class="row align-items-center">
          <div class="col-sm-5 col-4">
        <?php if($prev_post) {
          $ceremony_large_image =  wp_get_attachment_image_src( get_post_thumbnail_id($prev_post->ID), 'thumbnail', false, '' );
          $ceremony_large_image = $ceremony_large_image[0];
            echo '<a href="' . esc_url(get_permalink($prev_post->ID)) . '" class="gallery-control-link">';
            if ($ceremony_large_image) {
              echo'<span class="crmny-image"><img src="'.esc_url($ceremony_large_image).'" alt="'.$prev_post->post_title.'"></span>';
            }
              echo'<span class="control-link-info">
                <i class="fa fa-angle-double-left" aria-hidden="true"></i> <span class="control-link">'.esc_html($ceremony_prev_galry).'</span>
                <span class="control-link-title">' . $prev_post->post_title. '</span>
              </span>
            </a>';
         }
          echo '</div>';
          echo '<div class="col-sm-2 col-4 textcenter">
            <a href="'.esc_url($gallery_home_link).'" class="grid-view-link">
              <span class="grid-view-square"></span>
              <span class="grid-view-square"></span>
            </a>
          </div>';
        if($next_post) {
          $ceremony_large_image =  wp_get_attachment_image_src( get_post_thumbnail_id($next_post->ID), 'thumbnail', false, '' );
          $ceremony_large_image = $ceremony_large_image[0];
          echo'<div class="col-sm-5 col-4 textright">
            <a href="'. esc_url(get_permalink($next_post->ID)) .'" class="gallery-control-link">
              <span class="control-link-info">
                <span class="control-link">'.esc_html($ceremony_next_galry).'</span> <i class="fa fa-angle-double-right" aria-hidden="true"></i>
                <span class="control-link-title">'.$next_post->post_title.'</span>
              </span>';
              if ($ceremony_large_image) {
                echo'<span class="crmny-image"><img src="'.esc_url($ceremony_large_image).'" alt="'.$next_post->post_title.'"></span>';
              }
            echo'</a>
          </div>';
        } ?>
        </div>
      </div>
  <?php
  }
}

// information portfolio
if ( ! function_exists( 'ceremony_gallery_information_meta' ) ) {
function ceremony_gallery_information_meta( $meta_name, $meta_id ) {
    global $post;
    $gallery_meta  = get_post_meta( $post->ID, $meta_name, true );
    $informations = $gallery_meta[$meta_id];
    if ($informations) {
      $infos = $informations;
    } else {
      $infos = array();
    } ?>
      <ul>
        <?php
        foreach ( $infos as $key => $information ) {
          $meta_info = explode('<br>', nl2br($information['meta_info'], false));
          $meta_url = explode('<br>', nl2br($information['info_url'], false));

          if(!empty($information['info_url'])) {
            $meta_i = count($meta_info);
            $meta_u = count($meta_url);
            if ($meta_i > $meta_u) {
              $meta_info = array_slice($meta_info, 0, count($meta_url));
            } elseif($meta_u > $meta_i) {
              $meta_url = array_slice($meta_url, 0, count($meta_info));
            } else {
              $meta_info = $meta_info;
              $meta_url = $meta_url;
            }
            $totlal_info = array_combine($meta_info, $meta_url);
            ?>
            <li>
              <span><?php echo esc_html($information['title']); ?></span>
                <?php foreach ($totlal_info as $info => $url) {  ?>
                  <a href="<?php echo esc_url(trim($url));?>" class="asasas"><?php echo esc_html(trim($info)); ?></a>
                <?php } ?>
            </li>
          <?php } else { ?>
            <li>
              <span><?php echo esc_html($information['title']); ?></span>
              <?php foreach ($meta_info as $key => $info) { ?>
                <?php echo esc_html(trim($info)); ?>
              <?php } ?>
            </li>
          <?php
          }
        } ?>
      </ul>
<?php
}
}

/**
 * Pagination Function
 */
if ( ! function_exists( 'ceremony_default_paging_nav' ) ) {
  function ceremony_default_paging_nav($nav_query = NULL) {
    if ( function_exists('wp_pagenavi')) {
      echo '<div class="crmny-pagination">';
      wp_pagenavi();
      echo '</div>';
    } else {
      global $wp_query;
      $big = 999999999;
      $current = max( 1, get_query_var('paged') );
      $total = ($nav_query != NULL) ? $nav_query->max_num_pages : $wp_query->max_num_pages;

      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
      echo '<div class="crmny-pagination">';
      echo paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
        'format' => '?paged=%#%',
        'prev_text' => '<i class="fa fa-angle-left"></i>',
        'next_text' => ' <i class="fa fa-angle-right"></i>',
        'current' => $current,
        'total' => $total,
        'type' => 'list'
      ));
      echo '</div>';
      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
    }
  }
}

if ( ! function_exists( 'ceremony_paging_nav' ) ) {
  function ceremony_paging_nav($numpages = '', $pagerange = '', $paged='') {

      if (empty($pagerange)) {
        $pagerange = 2;
      }
      if (empty($paged)) {
        $paged = 1;
      } else {
        $paged = $paged;
      }
      if ($numpages == '') {
        global $wp_query;
        $numpages = $wp_query->max_num_pages;
        if(!$numpages) {
          $numpages = 1;
        }
      }
      global $wp_query;
      $big = 999999999;
      if($wp_query->max_num_pages != '1' ) { ?>
      <div class="crmny-pagination pagination-spacer-three">
        <?php echo paginate_links( array(
          'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
          'format' => '?paged=%#%',
          'prev_text' => '<i class="fa fa-angle-double-left" aria-hidden="true"></i>',
          'next_text' => '<i class="fa fa-angle-double-right" aria-hidden="true"></i>',
          'current' => $paged,
          'total' => $numpages,
          'type' => 'list'
        )); ?>
      </div>
    <?php }
  }
}

/**
 * Custom Pagination Function
 */
if ( ! function_exists( 'ceremony_custom_paging_nav' ) ) {
  function ceremony_custom_paging_nav($numpages = '', $pagerange = '', $paged='') {
    if (empty($pagerange)) {
      $pagerange = 2;
    }
    if (empty($paged)) {
      $paged = 1;
    } else {
      $paged = $paged;
    }
    if ($numpages == '') {
      global $wp_query;
      $numpages = $wp_query->max_num_pages;
      if(!$numpages) {
        $numpages = 1;
      }
    }
    $big = 999999999; ?>
    <div class="crmny-pagination pagination-spacer-three">
      <?php echo paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
        'format' => '?page=%#%',
        'prev_text' => '<i class="fa fa-angle-double-left" aria-hidden="true"></i>',
        'next_text' => '<i class="fa fa-angle-double-right" aria-hidden="true"></i>',
        'current' => $paged,
        'total' => $numpages,
        'type' => 'list'
      )); ?>
  </div>
<?php
  }
}
/* Added next class to wp-pagenavi*/
add_filter('wp_pagenavi_class_nextpostslink', 'ceremony_pagination_nextpostslink_class');
function ceremony_pagination_nextpostslink_class($class_name) {
  return 'next';
}

// Custom Post Type limit
function ceremony_custom_posts_per_page( $query ) {
  if ( post_type_exists( 'friends' ) ) {
    if ( is_post_type_archive('friends') ) {
      $friends_limit = cs_get_option('friends_limit');
      $friends_limit = $friends_limit ? $friends_limit : '6';
      if ( $query->query_vars['post_type'] === 'friends' ) $query->query_vars['posts_per_page'] = $friends_limit;
    }
  }
  if ( post_type_exists( 'gallery' ) ) {
    if ( is_post_type_archive('gallery') ) {
      $gallery_limit = cs_get_option('gallery_limit');
      $gallery_limit = $gallery_limit ? $gallery_limit : '6';
      if ( $query->query_vars['post_type'] === 'gallery' ) $query->query_vars['posts_per_page'] = $gallery_limit;
    }
    if (is_tax('gallery_category')) {
      $gallery_limit = cs_get_option('gallery_limit');
      $gallery_limit = $gallery_limit ? $gallery_limit : '6';
      $query->set('posts_per_page', $gallery_limit);
    }
  }
  return $query;
}
add_filter( 'pre_get_posts', 'ceremony_custom_posts_per_page' );

/* Remove Recent Comments Inline style */
add_filter( 'show_recent_comments_widget_style', '__return_false', 99 );

// Create post dropdown function for Contact Form 7 (not required)
add_action( 'wpcf7_init', 'ceremony_postselect2' );
function ceremony_postselect2() {
  wpcf7_add_form_tag( 'postlist', 'ceremony_custom_post_select2', true );
}

function ceremony_custom_post_select2( $tag ) {
  $events = tribe_get_events( array(
    'posts_per_page' => -1,
  ) );

  $output = "<select name='" . $tag['name'] . "' id='" . $tag['name'] . "'>";

  foreach ( $events as $event ) {
    $output .= '<option value="' . $event->ID .'">' . $event->post_title . '</option>';
  } // close foreach
  $output .= "</select>";
  return $output;
} // close function

// Create post dropdown function for Contact Form 7 (not required)
add_action( 'wpcf7_init', 'ceremony_postselect3' );
function ceremony_postselect3() {
  wpcf7_add_form_tag( 'postlist2', 'ceremony_custom_post_select3', true );
}
function ceremony_custom_post_select3( $tag ) {
  $events = tribe_get_events( array(
    'posts_per_page' => -1,
  ) );

  $output = "<select name='" . $tag['name'] . "' id='" . $tag['name'] . "' onchange='document.getElementById(" . $tag['name'] . ").value=this.value;'>";

  foreach ( $events as $event ) {
      $output .= '<option value="' . $event->ID .'">' . $event->post_date . '</option>';
  } // close foreach
  $output .= "</select>";
  return $output;
} // close function

// Elementor Function
if( ! function_exists( 'is_elementor' ) ) {
  function is_elementor(){
    $ceremony_page = get_post( cs_get_option('maintenance_mode_page') );
    if (Elementor\Plugin::instance()->db->is_built_with_elementor( $ceremony_page->ID )) {
      return true;
    } else {
      return null;
    }
  }
}
