<?php
/*
 * All WooCommerce Related Functions
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

if ( class_exists( 'WooCommerce' ) ) {

	/**
	* Insert the opening anchor tag for products in the loop.
	*/
	function ceremony_product_wrap_open() {
		echo '<div class="product-wrap">';
	}
	add_action( 'ceremony_open_wrap', 'ceremony_product_wrap_open', 1 );

	// Remove Description Title From Single Products Page
	add_filter('woocommerce_product_description_heading','ceremony_product_description_heading');

	function ceremony_product_description_heading() {
    return '';
	}

	/**
	 * Insert the closing anchor tag for products in the loop.
	 */
	function ceremony_product_wrap_close() {
		echo '</div>';
	}
	add_action( 'ceremony_close_wrap', 'ceremony_product_wrap_close', 1 );

  if ( ! function_exists( 'ceremony_template_loop_product_link_close' ) ) {
		/**
		 * Insert the opening anchor tag for products in the loop.
		 */
		function ceremony_template_loop_product_link_close() {
			echo '</a>';
		}
	}
	add_action( 'ceremony_loop_product_link_close', 'ceremony_template_loop_product_link_close', 10 );

  /* Remove Product Title action and added with h4 tag */
  remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );

  if ( ! function_exists( 'ceremony_template_loop_product_title' ) ) {

		/**
		 * Show the product title in the product loop. By default this is an H2.
		 */
		function ceremony_template_loop_product_title() {
			echo '<h4>' . get_the_title();
			echo '</h4>';
		}
	}
	add_action( 'woocommerce_shop_loop_item_title', 'ceremony_template_loop_product_title', 10 );

	// Added New function for wishlist
	if ( ! function_exists( 'ceremony_template_loop_product_wishlist' ) ) {

		/**
		 * Show the product title in the product loop. By default this is an H2.
		 */
		function ceremony_template_loop_product_wishlist() {
			if ( defined( 'YITH_WCWL' ) ) {
				echo do_shortcode('[yith_wcwl_add_to_wishlist icon="fa-heart-o"]');
			}
		}
	}
	add_action( 'ceremony_shop_loop_item_wishlist', 'ceremony_template_loop_product_wishlist', 10 );

	// Single Product Page - Share code into the woocommerce_template_single_sharing
	if ( function_exists( 'ceremony_wp_single_product_share_option' ) ) {
		add_action( 'woocommerce_share', 'ceremony_wp_single_product_share_option' );
	}

	// Add Image Parent div Class and catalog image + hover image
	remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);
	add_action( 'woocommerce_before_shop_loop_item_title', 'ceremony_loop_product_thumbnail', 10);
	if ( ! function_exists('ceremony_loop_product_thumbnail') ) {
	  function ceremony_loop_product_thumbnail() {
	    global $product;

	    $html = '';
	    $woo_need_hover_image = (cs_get_option('woo_hover_image')) ? true : false;
	    $woo_product_options = get_post_meta($product->get_id(), 'product_options', true );
			$woo_hover_image_change = isset($woo_product_options['product_hover_image_change']) ? $woo_product_options['product_hover_image_change'] : true;

	    if (has_post_thumbnail($product->get_id())) {
				$product_thumbnail_id = get_post_thumbnail_id();
				$product_thumbnail_title = get_the_title($product_thumbnail_id);
				$product_thumbnail_clog = wp_get_attachment_image_src($product_thumbnail_id, 'shop_catalog');
				$product_thumbnail_full = wp_get_attachment_image_src($product_thumbnail_id, 'full'); ?>

				<img width="<?php echo esc_attr($product_thumbnail_clog[1]); ?>'" height="<?php echo esc_attr($product_thumbnail_clog[2]); ?>'" src="<?php echo esc_url($product_thumbnail_clog[0]); ?>" alt="<?php echo esc_attr($product_thumbnail_title); ?>" class="attachment-shop_catalog size-shop_catalog wp-post-image default-product" />
			<?php } else {
	  		echo woocommerce_get_product_thumbnail();
	    }

	    if ($woo_need_hover_image && $woo_hover_image_change) {
	      $product_gallery_thumbnail_ids = $product->get_gallery_image_ids();
	      $product_thumbnail_alt_id = ($product_gallery_thumbnail_ids) ? reset($product_gallery_thumbnail_ids) : null;

	      if ($product_thumbnail_alt_id) {
	        $product_thumbnail_alt_title = get_the_title($product_thumbnail_alt_id);
	        $product_thumbnail_alt_src   = wp_get_attachment_image_src($product_thumbnail_alt_id, 'shop_catalog');
	        $product_thumbnail_alt_full  = wp_get_attachment_image_src($product_thumbnail_alt_id, 'full');

	        if ($product_thumbnail_alt_src) { ?>
	          <img width="<?php echo esc_attr($product_thumbnail_alt_src[1]); ?>" height="<?php echo esc_attr($product_thumbnail_alt_src[2]); ?>" src="<?php echo esc_url($product_thumbnail_alt_src[0]); ?>" alt="<?php echo esc_attr($product_thumbnail_alt_title); ?>" class="attachment-shop_catalog size-shop_catalog wp-post-image hover-product" />
	       <?php }
	      }
	    }
	  }
	}

	// WooCommerce Products per Page Limit
	add_filter( 'loop_shop_per_page', 'ceremony_product_limit', 20 );
	if ( ! function_exists('ceremony_product_limit') ) {
	  function ceremony_product_limit() {
	    $woo_limit = cs_get_option('theme_woo_limit');
	    $woo_limit = $woo_limit ? $woo_limit : '12';
	    return $woo_limit;
	  }
	}

  // Product Listing Pages - Add Add To Cart wrap div open
	add_action( 'woocommerce_before_shop_loop_item_title', 'ceremony_quick_view_wrap', 10, 2);
	if (!function_exists('ceremony_quick_view_wrap')) {
	  function ceremony_quick_view_wrap() {
	  	global $product;
	  	$link = apply_filters( 'woocommerce_loop_product_link', get_the_permalink(), $product );
	    echo '<span class="view-product"><i class="fa fa-eye" aria-hidden="true"></i> '.esc_html__('View Product', 'ceremony').'</span>';
	  }
	}

	// Remove Shop Page Title
	add_filter( 'woocommerce_show_page_title' , 'ceremony_hide_page_title' );
	function ceremony_hide_page_title() {
		return false;
	}

	// Single Product Single/Gallery Script
	add_action( 'after_setup_theme', 'ceremony_single_product_gallery_image' );
	function ceremony_single_product_gallery_image() {
		add_theme_support( 'wc-product-gallery-slider' );
	}

	// Single Product Page - Related Products Limit & columns
	add_filter( 'woocommerce_output_related_products_args', 'ceremony_related_products_args' );
  function ceremony_related_products_args( $args ) {
  	$woo_related_limit = cs_get_option('woo_related_limit');
  	$columns = cs_get_option('woo_product_columns');
  	if ($woo_related_limit) {
			$args['posts_per_page'] = (int)$woo_related_limit; // 4 related products
		} else {
			$args['posts_per_page'] = 4; // 4 related products
		}
		if($columns) {
			$args['columns'] = (int)$columns;
		} else {
			$args['columns'] = 3;
		}
		return $args;
	}

  // Added New action hook for cross sell(You May Also Like Section)
	if ( ! function_exists( 'ceremony_woocommerce_cross_sell_display' ) ) {

		function ceremony_woocommerce_cross_sell_display( $limit = 2, $columns = 2, $orderby = 'rand', $order = 'desc' ) {
			global $woocommerce_loop;

			if ( is_checkout() ) {
				return;
			}
			// Get visible cross sells then sort them at random.
			$cross_sells                 = array_filter( array_map( 'wc_get_product', WC()->cart->get_cross_sells() ), 'wc_products_array_filter_visible' );
			$woocommerce_loop['name']    = 'cross-sells';
			$woocommerce_loop['columns'] = apply_filters( 'woocommerce_cross_sells_columns', $columns );

			// Handle orderby and limit results.
			$orderby     = apply_filters( 'woocommerce_cross_sells_orderby', $orderby );
			$cross_sells = wc_products_array_orderby( $cross_sells, $orderby, $order );
			$limit       = apply_filters( 'woocommerce_cross_sells_total', $limit );
			$cross_sells = $limit > 0 ? array_slice( $cross_sells, 0, $limit ) : $cross_sells;

			wc_get_template( 'cart/cross-sells.php', array(
				'cross_sells'    => $cross_sells,
				// Not used now, but used in previous version of up-sells.php.
				'posts_per_page' => $limit,
				'orderby'        => $orderby,
				'columns'        => $columns,
			) );
		}
	}
	add_action( 'ceremony_woocommerce_cross_sell', 'ceremony_woocommerce_cross_sell_display', 10 );

	// Remove You May Also Like section
	remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
  $woo_single_crosssell = cs_get_option('woo_single_crosssell');
  if(!$woo_single_crosssell) {
		remove_action( 'ceremony_woocommerce_cross_sell', 'ceremony_woocommerce_cross_sell_display', 10 );
	}

  // Remove Related Products section
  $woo_single_related = cs_get_option('woo_single_related');
  if(!$woo_single_related) {
		// remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
  }

	// Product Column Limit - Shop Page
	add_filter('loop_shop_columns', 'ceremony_loop_columns');
	if ( ! function_exists('ceremony_loop_columns') ) {
		function ceremony_loop_columns() {
			return cs_get_option('woo_product_columns', '3');
		}
	}

	// Product Listing Pages - Remove Product Rating
  remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );

  // Removed Sale tag & added with our style
  remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
  if ( ! function_exists('ceremony_woo_sale_flash') ) {
		function ceremony_woo_sale_flash() {
			global $post, $product;
			if ( $product->is_on_sale() ) :
			echo apply_filters( 'woocommerce_sale_flash', '<div class="new-product"><span>' . esc_html__( 'Sale!', 'ceremony' ) . '</span></div>', $post, $product );
			endif;
		}
	}
	add_action( 'woocommerce_before_shop_loop_item_title', 'ceremony_woo_sale_flash', 10 );
	// Removed Sale tag & added with our style in  single product page
	remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10 );

  // Single Product Page - Moving the review star after review meta
	remove_action('woocommerce_review_before_comment_meta', 'woocommerce_review_display_rating', 10);
	remove_action('woocommerce_review_meta', 'woocommerce_review_display_meta', 10);

	add_action('woocommerce_review_meta', 'woocommerce_review_display_rating', 10);
  add_action('woocommerce_review_before_comment_meta', 'woocommerce_review_display_meta', 10, 2);

	// Custom Changes : changed default function "wc_get_gallery_image_html" to our custom function "ceremony_get_gallery_image_html" (Default function in includes/wc-template-functions.php )
	if ( ! function_exists('ceremony_get_gallery_image_html') ) {
		function ceremony_get_gallery_image_html( $attachment_id, $main_image = false ) {
			$flexslider        = (bool) apply_filters( 'woocommerce_single_product_flexslider_enabled', get_theme_support( 'wc-product-gallery-slider' ) );
			$gallery_thumbnail = wc_get_image_size( 'gallery_thumbnail' );
			$thumbnail_size    = apply_filters( 'woocommerce_gallery_thumbnail_size', array( $gallery_thumbnail['width'], $gallery_thumbnail['height'] ) );
			$image_size        = apply_filters( 'woocommerce_gallery_image_size', $flexslider || $main_image ? 'woocommerce_single' : $thumbnail_size );
			$full_size         = apply_filters( 'woocommerce_gallery_full_size', apply_filters( 'woocommerce_product_thumbnails_large_size', 'full' ) );
			$thumbnail_src     = wp_get_attachment_image_src( $attachment_id, $thumbnail_size );
			$full_src          = wp_get_attachment_image_src( $attachment_id, $full_size );
			$image             = wp_get_attachment_image( $attachment_id, $image_size, false, array(
				'title'                   => get_post_field( 'post_title', $attachment_id ),
				'data-caption'            => get_post_field( 'post_excerpt', $attachment_id ),
				'data-src'                => $full_src[0],
				'data-large_image'        => $full_src[0],
				'data-large_image_width'  => $full_src[1],
				'data-large_image_height' => $full_src[2],
				'class'                   => $main_image ? 'wp-post-image' : '',
			) );

			$woo_hide_zoom = cs_get_option('woo_hide_zoom');
			if($woo_hide_zoom) {
				$zoom_class = 'no-zoom';
				$popup_cls = ' hide-popup-icon';
			} else {
				$zoom_class = 'zoom-image';
				$popup_cls = '';
			}

			global $post, $product;
			if ( $product->is_on_sale() ) :
			$sale_flash = apply_filters( 'woocommerce_sale_flash', '<div class="new-product"><span>' . esc_html__( 'Sale!', 'ceremony' ) . '</span></div>', $post, $product );
		else:
			$sale_flash = '';
			endif;

			return '<div data-thumb="' . esc_url( $thumbnail_src[0] ) . '" class="woocommerce-product-gallery__image"><div class="'.$zoom_class.'">'.$sale_flash.'<a href="' . esc_url( $full_src[0] ) . '" class="woocommerce-main-image zoom">' . $image . '</a><div class="zoom-icon crmny-popup '.$popup_cls.'"><a href="' . esc_url( $full_src[0] ) . '"><i class="fa fa-arrows-alt" aria-hidden="true"></i></a></div></div></div>';
		}
	}

	// Remove You May Also Like section
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
  $woo_single_upsell = cs_get_option('woo_single_upsell');
  if($woo_single_upsell) {
		add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_upsells', 20);
		if (!function_exists('woocommerce_output_upsells')) {
			function woocommerce_output_upsells() {
				$columns = cs_get_option('up_sell_column');
				$columns = $columns ? $columns : '3';
			    woocommerce_upsell_display(3,$columns); // Display 3 products in rows of 3
			}
		}
	}

	// Wrap div's for cart page using actions
	add_action('woocommerce_before_cart_table', 'ceremony_before_cart_table');
	function ceremony_before_cart_table() {
		echo '<div class="row"><div class="custom-width-1">';
	}
	add_action('woocommerce_after_cart_table', 'ceremony_after_cart_table');
	function ceremony_after_cart_table() {
		echo '</div>';
	}
	
	add_action('woocommerce_after_cart_table', 'ceremony_before_cart_totals');
	function ceremony_before_cart_totals() {
		echo '<div class="custom-width-2">';
	}
	add_action('woocommerce_after_cart', 'ceremony_after_cart_totals');
	function ceremony_after_cart_totals() {
		echo '</div></div>';
	}

	/**
	* Add new register fields for WooCommerce registration.
	*/
	function wooc_extra_register_fields() { ?>

	 <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
	   <label for="reg_billing_first_name"><?php esc_html_e( 'First name', 'ceremony' ); ?><span class="required">*</span></label>
	   <input type="text" class="input-text" name="billing_first_name" id="reg_billing_first_name" value="<?php if ( ! empty( $_POST['billing_first_name'] ) ) esc_attr( $_POST['billing_first_name'] ); ?>" />
	 </p>
	 <div class="clear"></div>
	<?php
	}
	add_action( 'woocommerce_register_form_start', 'wooc_extra_register_fields' );

	/**
	* Validate the extra register fields.
	*/
	function wooc_validate_extra_register_fields( $username, $email, $validation_errors ) {

		if ( isset( $_POST['billing_first_name'] ) && empty( $_POST['billing_first_name'] ) ) {
		  $validation_errors->add( 'billing_first_name_error', esc_html__( 'Error: First name is required!', 'ceremony' ) );
		}

	}
	add_action( 'woocommerce_register_post', 'wooc_validate_extra_register_fields', 10, 3 );

	/**
	* Save the extra register fields.
	*/
	function wooc_save_extra_register_fields( $customer_id ) {

		if ( isset( $_POST['billing_first_name'] ) ) {

			// WordPress default first name field.
			update_user_meta( $customer_id, 'first_name', sanitize_text_field( $_POST['billing_first_name'] ) );

			// WooCommerce billing first name.
			update_user_meta( $customer_id, 'billing_first_name', sanitize_text_field( $_POST['billing_first_name'] ) );
		}

	}
	add_action( 'woocommerce_created_customer', 'wooc_save_extra_register_fields' );

} // class_exists => WooCommerce
