<?php
/*
 * All Theme Options for Ceremony theme.
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

function ceremony_vt_settings( $settings ) {
  $settings           = array(
    'menu_title'      => CEREMONY_NAME . esc_html__(' Options', 'ceremony'),
    'menu_slug'       => sanitize_title(CEREMONY_NAME) . '_options',
    'menu_type'       => 'menu',
    'menu_icon'       => 'dashicons-awards',
    'menu_position'   => '4',
    'ajax_save'       => false,
    'show_reset_all'  => true,
    'framework_title' => CEREMONY_NAME .' <small>V-'. CEREMONY_VERSION .' by <a href="'. CEREMONY_BRAND_URL .'" target="_blank">'. CEREMONY_BRAND_NAME .'</a></small>',
  );
  return $settings;
}
add_filter( 'cs_framework_settings', 'ceremony_vt_settings' );

// Theme Framework Options
function ceremony_vt_options( $options ) {

  $options      = array(); // remove old options
  // ------------------------------
  // Theme Brand
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_brand',
    'title'    => esc_html__('Logo', 'ceremony'),
    'icon'     => 'fa fa-bookmark',
    'fields' => array(

      // Site Logo
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Site Logo', 'ceremony')
      ),
      array(
        'id'    => 'brand_logo_default',
        'type'  => 'image',
        'title' => esc_html__('Default Logo', 'ceremony'),
        'info'  => esc_html__('Upload your default logo here. If you not upload, then site title will load in this logo location.', 'ceremony'),
        'add_title' => esc_html__('Add Logo', 'ceremony'),
      ),
      array(
        'id'          => 'logo_width',
        'type'        => 'text',
        'title'       => esc_html__('Logo Width', 'ceremony'),
        'unit'        => 'px',
      ),
      array(
        'id'          => 'logo_height',
        'type'        => 'text',
        'title'       => esc_html__('Logo Height', 'ceremony'),
        'unit'        => 'px',
      ),
      array(
        'id'          => 'brand_logo_top',
        'type'        => 'number',
        'title'       => esc_html__('Logo Top Space', 'ceremony'),
        'attributes'  => array( 'placeholder' => 5 ),
        'unit'        => 'px',
      ),
      array(
        'id'          => 'brand_logo_bottom',
        'type'        => 'number',
        'title'       => esc_html__('Logo Bottom Space', 'ceremony'),
        'attributes'  => array( 'placeholder' => 5 ),
        'unit'        => 'px',
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Transparent Header', 'ceremony')
      ),
      array(
        'id'    => 'transparent_logo_default',
        'type'  => 'image',
        'title' => esc_html__('Transparent Logo', 'ceremony'),
        'info'  => esc_html__('Upload your transparent header logo here. This logo is used in transparent header by enabled in each pages.', 'ceremony'),
        'add_title' => esc_html__('Add Transparent Logo', 'ceremony'),
      ),

      // WordPress Admin Logo
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('WordPress Admin Logo', 'ceremony')
      ),
      array(
        'id'    => 'brand_logo_wp',
        'type'  => 'image',
        'title' => esc_html__('Login logo', 'ceremony'),
        'info'  => esc_html__('Upload your WordPress login page logo here.', 'ceremony'),
        'add_title' => esc_html__('Add Login Logo', 'ceremony'),
      ),

    ),
  );

  // ------------------------------
  // Layout
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_layout',
    'title'  => esc_html__('Layout', 'ceremony'),
    'icon'   => 'fa fa-file-text'
  );
  $options[]      = array(
    'name'        => 'theme_general',
    'title'       => esc_html__('General', 'ceremony'),
    'icon'        => 'fa fa-wrench',

    // begin: fields
    'fields'      => array(

      // -----------------------------
      // Begin
      // -----------------------------
      array(
        'id'    => 'theme_preloader',
        'type'  => 'switcher',
        'title' => esc_html__('Preloader', 'ceremony'),
        'info' => esc_html__('Turn off if you don\'t want preloader.', 'ceremony'),
      ),
      array(
        'id'    => 'theme_btotop',
        'type'  => 'switcher',
        'title' => esc_html__('Back To Top', 'ceremony'),
        'info' => esc_html__('Turn off if you don\'t want back to top button.', 'ceremony'),
        'default' => true,
      ),
      array(
        'id'             => 'music_icon',
        'type'           => 'select',
        'title'          => esc_html__('Music Icon', 'ceremony'),
        'options'        => array(
          'hide' => esc_html__('Hide', 'ceremony'),
          'play' => esc_html__('Default Play', 'ceremony'),
          'pause' => esc_html__('Default Pause', 'ceremony'),
        ),
        'info' => esc_html__('Select music option', 'ceremony'),
      ),
      array(
        'id'             => 'audio_file',
        'type'           => 'upload',
        'title'          => 'Upload mp3 file',
      ),
      array(
        'id'    => 'theme_img_resizer',
        'type'  => 'switcher',
        'title' => esc_html__('Disable Image Resizer?', 'ceremony'),
        'info' => esc_html__('Turn on if you don\'t want image resizer.', 'ceremony'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Search Type', 'ceremony'),
      ),
      array(
        'id'             => 'search_type',
        'type'           => 'select',
        'title'          => esc_html__('Search Page Style', 'ceremony'),
        'options'        => array(
          'normal' => esc_html__('Default', 'ceremony'),
          'post_type_search' => esc_html__('Post Type Search', 'ceremony'),
        ),
        'info' => esc_html__('Select Search Page Style', 'ceremony'),
      ),

    ), // end: fields

  );

  // ------------------------------
  // Header Sections
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_header_tab',
    'title'    => esc_html__('Header', 'ceremony'),
    'icon'     => 'fa fa-bars',
    'sections' => array(

      // header design tab
      array(
        'name'     => 'header_design_tab',
        'title'    => esc_html__('Design', 'ceremony'),
        'icon'     => 'fa fa-magic',
        'fields'   => array(
          // Header Select
          array(
            'id'           => 'select_header_design',
            'type'         => 'image_select',
            'title'        => esc_html__('Select Header Design', 'ceremony'),
            'options'      => array(
              'style_one'    => CEREMONY_CS_IMAGES .'/hs-1.png',
              'style_two'    => CEREMONY_CS_IMAGES .'/hs-2.png',
              'style_three'  => CEREMONY_CS_IMAGES .'/hs-3.png',
              'style_four'  => CEREMONY_CS_IMAGES .'/hs-4.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'header_design',
            ),
            'radio'        => true,
            'default'   => 'style_one',
            'info' => esc_html__('Select your header design, following options will may differ based on your selection of header design.', 'ceremony'),
          ),
          array(
            'id'        => 'fullwidth_header',
            'type'      => 'select',
            'title'     => esc_html__('Fullwidth Header', 'ceremony'),
            'options'   => array(
              'container' => 'Container Width',
              'fullwidth'   => 'Fullwidth',
            ),
            'dependency' => array('header_design', '==', 'style_one'),
          ),
          array(
            'id'        => 'transparent_header',
            'type'      => 'select',
            'title'     => esc_html__('Transparent Header', 'ceremony'),
            'options'   => array(
              'normal'   => 'Normal Header(Not Transparent)',
              'transparent' => 'Transparent Header',
            ),
            'dependency' => array('header_design', '==', 'style_two'),
          ),
          array(
            'id'    => 'need_content',
            'type'  => 'switcher',
            'title' => esc_html__('Need Header Content', 'ceremony'),
            'default' => true,
          ),
          array(
            'id'              => 'header_address_info',
            'title'           => esc_html__('Header Content', 'ceremony'),
            'desc'            => esc_html__('Add your header content here. Example : Buttons', 'ceremony'),
            'type'            => 'textarea',
            'shortcode'       => true,
            'dependency'   => array('need_content', '==', 'true'),
          ),
          array(
            'id'              => 'header_address_info_secondary',
            'title'           => esc_html__('Header Content Secondary', 'ceremony'),
            'desc'            => esc_html__('Add your header secondary content here. Example : Buttons,Address info', 'ceremony'),
            'type'            => 'textarea',
            'shortcode'       => true,
            'dependency'   => array('need_content|header_design', '==|==', 'true|style_three'),
          ),
          // Header Select
          // Extra's
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Extra\'s', 'ceremony'),
          ),
          array(
            'id'        => 'sticky_header',
            'type'      => 'select',
            'title'     => esc_html__('Sticky Header', 'ceremony'),
            'options'   => array(
              'not-sticky'   => 'Not Sticky',
              'sticky' => 'Sticky',
            ),
          ),
          array(
            'id'        => 'sticky_footer',
            'type'      => 'select',
            'title'     => esc_html__('Sticky Footer', 'ceremony'),
            'options'   => array(
              'not-sticky'   => 'Not Sticky',
              'sticky' => 'Sticky',
            ),
          ),
          array(
            'id'        => 'search_icon',
            'type'      => 'select',
            'title'     => esc_html__('Search Icon', 'ceremony'),
            'options'   => array(
              'hide'   => 'Hide',
              'show' => 'Show',
            ),
          ),
          array(
            'id'        => 'cart_icon',
            'type'      => 'select',
            'title'     => esc_html__('Cart Icon', 'ceremony'),
            'options'   => array(
              'hide'   => 'Hide',
              'show' => 'Show',
            ),
          ),
          array(
            'id'          => 'mobile_breakpoint',
            'type'        => 'text',
            'title'       => esc_html__('Mobile Menu Starts from?', 'ceremony'),
            'attributes'  => array( 'placeholder' => '1199' ),
            'info' => esc_html__('Just put numeric value only. Like : 1199. Don\'t use px or any other units.', 'ceremony'),
          ),

        )
      ),

      // header top bar
      array(
        'name'     => 'header_top_bar_tab',
        'title'    => esc_html__('Top Bar', 'ceremony'),
        'icon'     => 'fa fa-minus',
        'fields'   => array(

          array(
            'id'          => 'top_bar',
            'type'        => 'switcher',
            'title'       => esc_html__('Hide Top Bar', 'ceremony'),
            'on_text'     => esc_html__('Yes', 'ceremony'),
            'off_text'    => esc_html__('No', 'ceremony'),
            'default'     => false,
          ),
          array(
            'id'          => 'top_bar_in_responsive',
            'type'        => 'switcher',
            'title'       => esc_html__('Hide Top Bar in Responsive', 'ceremony'),
            'on_text'     => esc_html__('Yes', 'ceremony'),
            'off_text'    => esc_html__('No', 'ceremony'),
            'default'     => false,
          ),
          array(
            'id'        => 'fullwidth_topbar',
            'type'      => 'select',
            'title'     => esc_html__('Fullwidth TopBar', 'ceremony'),
            'options'   => array(
              'container' => 'Container Width',
              'fullwidth'   => 'Fullwidth',
            ),
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'top_left',
            'title'       => esc_html__('Top Left Block', 'ceremony'),
            'desc'        => esc_html__('Top bar left block.', 'ceremony'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'top_right',
            'title'       => esc_html__('Top Right Block', 'ceremony'),
            'desc'        => esc_html__('Top bar right block.', 'ceremony'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),

          array(
            'id'          => 'topbar_left_width',
            'type'        => 'text',
            'title'       => esc_html__('Top Left Width in %', 'ceremony'),
            'attributes'  => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'topbar_right_width',
            'type'        => 'text',
            'title'       => esc_html__('Top Right Width in %', 'ceremony'),
            'attributes'  => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('top_bar', '==', false),
          ),

        )
      ),

      // header banner
      array(
        'name'     => 'header_banner_tab',
        'title'    => esc_html__('Title Bar (or) Banner', 'ceremony'),
        'icon'     => 'fa fa-bullhorn',
        'fields'   => array(

          // Title Area
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Title Area', 'ceremony')
          ),
          array(
            'id'      => 'need_title_bar',
            'type'    => 'switcher',
            'title'   => esc_html__('Title Bar', 'ceremony'),
            'label'   => esc_html__('If you want title bar in your sub-pages, please turn this ON.', 'ceremony'),
            'default'    => true,
          ),
          array(
            'id'             => 'title_bar_padding',
            'type'           => 'select',
            'title'          => esc_html__('Padding Spaces Top & Bottom', 'ceremony'),
            'options'        => array(
              'padding-default' => esc_html__('Default Spacing', 'ceremony'),
              'padding-xs' => esc_html__('Extra Small Padding', 'ceremony'),
              'padding-sm' => esc_html__('Small Padding', 'ceremony'),
              'padding-md' => esc_html__('Medium Padding', 'ceremony'),
              'padding-lg' => esc_html__('Large Padding', 'ceremony'),
              'padding-xl' => esc_html__('Extra Large Padding', 'ceremony'),
              'padding-no' => esc_html__('No Padding', 'ceremony'),
              'padding-custom' => esc_html__('Custom Padding', 'ceremony'),
            ),
            'dependency'   => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'             => 'title_area_align',
            'type'           => 'select',
            'title'          => esc_html__('Title Area Text Align', 'ceremony'),
            'options'        => array(
              'text-center' => esc_html__('Center', 'ceremony'),
              'text-left' => esc_html__('Left', 'ceremony'),
              'text-right' => esc_html__('Right', 'ceremony'),
            ),
            'dependency'   => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'             => 'titlebar_top_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Top', 'ceremony'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding|need_title_bar', '==|==', 'padding-custom|true' ),
          ),
          array(
            'id'             => 'titlebar_bottom_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Bottom', 'ceremony'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding|need_title_bar', '==|==', 'padding-custom|true' ),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Breadcrumbs', 'ceremony'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Background Options', 'ceremony'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'      => 'titlebar_bg',
            'type'    => 'background',
            'title'   => esc_html__('Background', 'ceremony'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'      => 'titlebar_bg_overlay_color',
            'type'    => 'color_picker',
            'title'   => esc_html__('Overlay Color', 'ceremony'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),

        )
      ),
      // Side Bar Menu
      array(
        'name'     => 'header_sidebar_menu_tab',
        'title'    => esc_html__('Overlay Menu', 'ceremony'),
        'icon'     => 'fa fa-minus',
        'fields'   => array(

          array(
            'id'             => 'fixed_nav',
            'type'           => 'select',
            'title'          => esc_html__('Overlay Navigation', 'ceremony'),
            'options'        => array(
              'hide' => esc_html__('Hide', 'ceremony'),
              'show' => esc_html__('Show', 'ceremony'),
            ),
            'info' => esc_html__('Turn On if you want to show overlay navigation.', 'ceremony'),
          ),
          array(
            'id'          => 'side_menu_align',
            'title'       => esc_html__('Side Menu Alignment', 'ceremony'),
            'type'        => 'select',
            'options'        => array(
              'right' => esc_html__('Right', 'ceremony'),
              'left' => esc_html__('Left', 'ceremony'),
            ),
            'dependency'  => array('fixed_nav', '==', 'show'),
          ),
          array(
            'id'          => 'side_menu_style',
            'title'       => esc_html__('Select Side Menu', 'ceremony'),
            'type'        => 'select',
            'options'        => array(
              'default' => esc_html__('Default Menu', 'ceremony'),
              'custom' => esc_html__('Custom Menu', 'ceremony'),
            ),
            'dependency'  => array('fixed_nav', '==', 'show'),
          ),
          array(
            'id'             => 'choose_menu',
            'type'           => 'select',
            'title'          => esc_html__('Choose Menu', 'ceremony'),
            'desc'          => esc_html__('Choose custom menus for this page.', 'ceremony'),
            'options'        => 'menus',
            'default_option' => esc_html__('Select your menu', 'ceremony'),
            'dependency'  => array('side_menu_style|fixed_nav', '==|==', 'default|show'),
          ),

          array(
            "type"        =>'textarea',
            "title"     => esc_html__('Custom Menu Shortcode', 'ceremony'),
            "id"  => "custom_menu",
            'shortcode'   => true,
            "info" => esc_html__( "Include custom shortcode to display in side menu section.", 'ceremony'),
            'dependency'  => array('side_menu_style|fixed_nav', '==|==', 'custom|show'),
          ),
          array(
            "type"        =>'textarea',
            "title"     => esc_html__('Social Shortcode', 'ceremony'),
            "id"  => "social_shortcode",
            'shortcode'   => true,
            "info" => esc_html__( "Include social shortcode to display in side menu section.", 'ceremony'),
            'dependency'  => array('fixed_nav', '==', 'show'),
          ),
          array(
            'id'      => 'select_mean_menu',
            'type'    => 'switcher',
            'title'   => esc_html__('Mean Menu', 'ceremony'),
            'label'   => esc_html__('If you want this menu as mean menu, Please turn this ON.', 'ceremony'),
            'dependency'  => array('fixed_nav', '==', 'show'),
          ),

        )
      ),

    ),
  );

  // ------------------------------
  // Footer Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'footer_section',
    'title'    => esc_html__('Footer', 'ceremony'),
    'icon'     => 'fa fa-ellipsis-h',
    'fields'   => array(

      // Footer Widget Block
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Footer Widget Block', 'ceremony')
      ),
      array(
        'id'    => 'footer_widget_block',
        'type'  => 'switcher',
        'title' => esc_html__('Enable Widget Block', 'ceremony'),
        'info' => esc_html__('If you turn this ON, then Goto : Appearance > Widgets. There you can see Footer Widget 1,2,3 or 4 Widget Area, add your widgets there.', 'ceremony'),
        'default' => true,
      ),
      array(
        'id'    => 'footer_widget_layout',
        'type'  => 'image_select',
        'title' => esc_html__('Widget Layouts', 'ceremony'),
        'info' => esc_html__('Choose your footer widget layouts.', 'ceremony'),
        'default' => 4,
        'options' => array(
          1   => CEREMONY_CS_IMAGES . '/footer/footer-1.png',
          2   => CEREMONY_CS_IMAGES . '/footer/footer-2.png',
          3   => CEREMONY_CS_IMAGES . '/footer/footer-3.png',
          4   => CEREMONY_CS_IMAGES . '/footer/footer-4.png',
          5   => CEREMONY_CS_IMAGES . '/footer/footer-5.png',
          6   => CEREMONY_CS_IMAGES . '/footer/footer-6.png',
          7   => CEREMONY_CS_IMAGES . '/footer/footer-7.png',
          8   => CEREMONY_CS_IMAGES . '/footer/footer-8.png',
          9   => CEREMONY_CS_IMAGES . '/footer/footer-9.png',
          10   => CEREMONY_CS_IMAGES . '/footer/footer-10.png',
        ),
        'radio'       => true,
        'dependency'  => array('footer_widget_block', '==', true),
      ),
      array(
        'id'             => 'footer_widget_align',
        'type'           => 'select',
        'title'          => esc_html__('Widget Align', 'ceremony'),
        'options'        => array(
          '' => esc_html__('Select Footer Align', 'ceremony'),
          'center-align' => esc_html__('Center', 'ceremony'),
          'left-align' => esc_html__('Left', 'ceremony'),
          'right-align' => esc_html__('Right', 'ceremony'),
        ),
        'dependency'  => array('footer_widget_layout_1', '==', true),
      ),
       // Copyright
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Copyright Layout', 'ceremony'),
      ),
      array(
        'id'    => 'need_copyright',
        'type'  => 'switcher',
        'title' => esc_html__('Enable Copyright Section', 'ceremony'),
        'default' => true,
      ),
      array(
        'id'    => 'footer_copyright_layout',
        'type'  => 'image_select',
        'title' => esc_html__('Select Copyright Layout', 'ceremony'),
        'info' => esc_html__('In above image, blue box is copyright text and yellow box is secondary text.', 'ceremony'),
        'default'      => 'copyright-3',
        'options'      => array(
          'copyright-1'    => CEREMONY_CS_IMAGES .'/footer/copyright-1.png',
          'copyright-2'    => CEREMONY_CS_IMAGES .'/footer/copyright-2.png',
          'copyright-3'    => CEREMONY_CS_IMAGES .'/footer/copyright-3.png',
          ),
        'radio'        => true,
        'dependency'     => array('need_copyright', '==', true),
      ),
      array(
        'id'    => 'copyright_text',
        'type'  => 'textarea',
        'title' => esc_html__('Copyright Text', 'ceremony'),
        'shortcode' => true,
        'dependency' => array('need_copyright', '==', true),
        'after'       => 'Helpful shortcodes: [ceremony_current_year] [ceremony_home_url] or any shortcode.',
      ),

      // Copyright Another Text
      array(
        'type'    => 'notice',
        'class'   => 'warning cs-vt-heading',
        'content' => esc_html__('Copyright Secondary Text', 'ceremony'),
        'dependency'     => array('need_copyright', '==', true),
      ),
      array(
        'id'    => 'secondary_text',
        'type'  => 'textarea',
        'title' => esc_html__('Secondary Text', 'ceremony'),
        'shortcode' => true,
        'dependency' => array('need_copyright', '==', 'true'),
      ),
    ),
  );

  // ------------------------------
  // Design
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_design',
    'title'  => esc_html__('Design', 'ceremony'),
    'icon'   => 'fa fa-magic'
  );

  // ------------------------------
  // color section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_color_section',
    'title'    => esc_html__('Colors', 'ceremony'),
    'icon'     => 'fa fa-eyedropper',
    'fields' => array(

      array(
        'type'    => 'heading',
        'content' => esc_html__('Color Options', 'ceremony'),
      ),
      array(
        'type'    => 'subheading',
        'wrap_class' => 'color-tab-content',
        'content' => esc_html__('All color options are available in our theme customizer. The reason of we used customizer options for color section is because, you can choose each part of color from there and see the changes instantly using customizer. Highly customizable colors are in Appearance > Customize', 'ceremony'),
      ),

    ),
  );

  // ------------------------------
  // Typography section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_typo_section',
    'title'    => esc_html__('Typography', 'ceremony'),
    'icon'     => 'fa fa-header',
    'fields' => array(

      // Start fields
      array(
        'id'                  => 'typography',
        'type'                => 'group',
        'fields'              => array(
          array(
            'id'              => 'title',
            'type'            => 'text',
            'title'           => esc_html__('Title', 'ceremony'),
          ),
          array(
            'id'              => 'selector',
            'type'            => 'textarea',
            'title'           => esc_html__('Selector', 'ceremony'),
            'info'           => esc_html__('Enter css selectors like : body, .custom-class', 'ceremony'),
          ),
          array(
            'id'              => 'font',
            'type'            => 'typography',
            'title'           => esc_html__('Font Family', 'ceremony'),
          ),
          array(
            'id'              => 'css',
            'type'            => 'textarea',
            'title'           => esc_html__('Custom CSS', 'ceremony'),
          ),
        ),
        'button_title'        => esc_html__('Add New Typography', 'ceremony'),
        'accordion_title'     => esc_html__('New Typography', 'ceremony'),
        'default'             => array(
          array(
            'title'           => esc_html__('Body Typography', 'ceremony'),
            'selector'        => 'body, form label, .about-info .socials-label, .gallery-meta .socials-label, .crmny-blog-share .socials-label, .woocommerce .woocommerce-result-count, .woocommerce-page .woocommerce-result-count, .woocommerce ul.cart_list, .woocommerce ul.product_list_widget, .product-share .socials-label, .woocommerce #reviews #comments ol.commentlist li .comment-text p.meta strong, .woocommerce .wc_payment_method .wpcf7-list-item-label, .tribe-events-page-title, .woocommerce div.product p.price ins, .woocommerce div.product span.price ins, .woocommerce div.product p.price .woocommerce-Price-amount.amount, .woocommerce div.product span.price .woocommerce-Price-amount.amount',
            'font'            => array(
              'family'        => 'Poppins',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Menu Typography', 'ceremony'),
            'selector'        => '.crmny-navigation, .crmny-navigation > ul > li, .mean-container .mean-nav ul li a',
            'font'            => array(
              'family'        => 'Poppins',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Sub Menu Typography', 'ceremony'),
            'selector'        => '.dropdown-nav > li, .dropdown-nav, .mean-container .mean-nav ul.sub-menu li a',
            'font'            => array(
              'family'        => 'Poppins',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Headings Typography', 'ceremony'),
            'selector'        => 'h1, h2, h3, h4, h5, h6, .text-logo',
            'font'            => array(
              'family'        => 'Poppins',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Shortcode Elements Primary Font', 'ceremony'),
            'selector'        => 'p, .crmny-btn, .cart-counter, .countdown-title, .gallery-detail-link, .function-time, .blog-info ul, .socials-label, .copyright-title, .crmny-topbar ul, .author-designation, .proposal-startup, .stats-title, .photoshoot-subtitle, .suit-title, .event-menu-item ul, .event-info ul, .error-subtitle, .control-link, .gallery-details-wrap ul, .crmny-widget ul, .tag-widget a, .widget_tag_cloud a, .crmny-blog-tags a, .crmny-comments-area .crmny-comments-meta .comments-date, .amount-label, .woocommerce div.product .product_meta.meta-categories, .checkbox .wpcf7-list-item-label, .product-stats-title, .woocommerce-error, .woocommerce-info, .woocommerce-message, .woocommerce form .wpcf7-list-item-label, .woocommerce .woocommerce-checkout-review-order table.shop_table tbody td, .woocommerce li.wc_payment_method a, .yith-wcwl-add-to-wishlist a, .crmny-blog-excerpt, .woocommerce ul.products li.product .button',
            'font'            => array(
              'family'        => 'Raleway',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Shortcode Elements Secondary Font', 'ceremony'),
            'selector'        => '.caption-title, .place-title, .missing-title, .quote-title, .couple-name, .marriage-date, .banner-caption-title, .offer-title, .location-title, .getting-engaged-title',
            'font'            => array(
              'family'        => 'Alex Brush',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Example Usage', 'ceremony'),
            'selector'        => '.your-custom-class',
            'font'            => array(
              'family'        => 'Montserrat',
              'variant'       => 'regular',
            ),
          ),
        ),
      ),

      // Subset
      array(
        'id'                  => 'subsets',
        'type'                => 'select',
        'title'               => esc_html__('Subsets', 'ceremony'),
        'class'               => 'chosen',
        'options'             => array(
          'latin'             => 'latin',
          'latin-ext'         => 'latin-ext',
          'cyrillic'          => 'cyrillic',
          'cyrillic-ext'      => 'cyrillic-ext',
          'greek'             => 'greek',
          'greek-ext'         => 'greek-ext',
          'vietnamese'        => 'vietnamese',
          'devanagari'        => 'devanagari',
          'khmer'             => 'khmer',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Subsets',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( 'latin' ),
      ),

      array(
        'id'                  => 'font_weight',
        'type'                => 'select',
        'title'               => esc_html__('Font Weights', 'ceremony'),
        'class'               => 'chosen',
        'options'             => array(
          '300'   => 'Light 300',
          '400'   => 'Regular 400',
          '500'   => 'Medium 500',
          '600'   => 'Semi Bold 600',
          '700'   => 'Bold 700',
          '800'   => 'Extra Bold 800',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Font Weight',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( '300', '400', '500', '600', '700', '800' ),
      ),

      // Custom Fonts Upload
      array(
        'id'                 => 'font_family',
        'type'               => 'group',
        'title'              => 'Upload Custom Fonts',
        'button_title'       => 'Add New Custom Font',
        'accordion_title'    => 'Adding New Font',
        'accordion'          => true,
        'desc'               => 'It is simple. Only add your custom fonts and click to save. After you can check "Font Family" selector. Do not forget to Save!',
        'fields'             => array(

          array(
            'id'             => 'name',
            'type'           => 'text',
            'title'          => 'Font-Family Name',
            'attributes'     => array(
              'placeholder'  => 'for eg. Arial'
            ),
          ),

          array(
            'id'             => 'ttf',
            'type'           => 'upload',
            'title'          => 'Upload .ttf <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.ttf</i>',
            ),
          ),

          array(
            'id'             => 'eot',
            'type'           => 'upload',
            'title'          => 'Upload .eot <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.eot</i>',
            ),
          ),

          array(
            'id'             => 'otf',
            'type'           => 'upload',
            'title'          => 'Upload .otf <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.otf</i>',
            ),
          ),

          array(
            'id'             => 'woff',
            'type'           => 'upload',
            'title'          => 'Upload .woff <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.woff</i>',
            ),
          ),

          array(
            'id'             => 'css',
            'type'           => 'textarea',
            'title'          => 'Extra CSS Style <small><i>(optional)</i></small>',
            'attributes'     => array(
              'placeholder'  => 'for eg. font-weight: normal;'
            ),
          ),

        ),
      ),
      // End All field

    ),
  );

  // ------------------------------
  // Pages
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_pages',
    'title'  => esc_html__('Pages', 'ceremony'),
    'icon'   => 'fa fa-files-o'
  );

  // ------------------------------
  // Gallery Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'gallery_section',
    'title'    => esc_html__('Gallery', 'ceremony'),
    'icon'     => 'fa fa-briefcase',
    'fields' => array(

      // gallery name change
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Name Change', 'ceremony')
      ),
      array(
        'id'      => 'theme_gallery_name',
        'type'    => 'text',
        'title'   => esc_html__('Gallery Name', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => 'Gallery'
        ),
      ),
      array(
        'id'      => 'theme_gallery_slug',
        'type'    => 'text',
        'title'   => esc_html__('Gallery Slug', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => 'gallery-item'
        ),
      ),
      array(
        'id'      => 'theme_gallery_cat_slug',
        'type'    => 'text',
        'title'   => esc_html__('Gallery Category Slug', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => 'gallery-category'
        ),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'danger',
        'content' => esc_html__('Important: Please do not set gallery slug and page slug as same. It\'ll not work.', 'ceremony')
      ),
      // Gallery Name

      // gallery listing
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Gallery Style', 'ceremony')
      ),
      array(
        'id'             => 'gallery_style',
        'type'           => 'select',
        'title'          => esc_html__('Gallery Style', 'ceremony'),
        'options'        => array(
          'one' => esc_html__('Style One (Grid)', 'ceremony'),
          'two' => esc_html__('Style Two (Masonry)', 'ceremony'),
          'three' => esc_html__('Style Three (Grid Two)', 'ceremony'),
          'four' => esc_html__('Style Four (Masonry Two)', 'ceremony'),
        ),
      ),
      array(
        'id'             => 'gallery_column',
        'type'           => 'select',
        'title'          => esc_html__('Gallery Column', 'ceremony'),
        'options'        => array(
          '4' => esc_html__('Four Columns', 'ceremony'),
          '3' => esc_html__('Three Columns', 'ceremony'),
          '2' => esc_html__('Two Columns', 'ceremony'),
        ),
        'dependency'     => array('gallery_style', '==', 'one'),
        'default_option'     => esc_html__('Select Gallery Column', 'ceremony'),
      ),
      array(
        'id'      => 'gallery_limit',
        'type'    => 'text',
        'title'   => esc_html__('Gallery Limit', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => '10'
        ),
      ),
      array(
        'id'      => 'gallery_space',
        'type'    => 'text',
        'title'   => esc_html__('Gallery Space', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => '10'
        ),
      ),
      array(
        'id'      => 'gallery_show_category',
        'type'    => 'text',
        'title'   => esc_html__('Gallery Categorys', 'ceremony'),
        'info'   => esc_html__('Enter category SLUGS (comma separated) you want to display.', 'ceremony'),
      ),
      array(
        'id'             => 'gallery_orderby',
        'type'           => 'select',
        'title'          => esc_html__('Order By', 'ceremony'),
        'options'        => array(
          'none' => esc_html__('None', 'ceremony'),
          'ID' => esc_html__('ID', 'ceremony'),
          'author' => esc_html__('Author', 'ceremony'),
          'title' => esc_html__('Title', 'ceremony'),
          'date' => esc_html__('Date', 'ceremony'),
          'name' => esc_html__('Name', 'ceremony'),
          'modified' => esc_html__('Modified', 'ceremony'),
          'rand' => esc_html__('Random', 'ceremony'),
          'menu_order' => esc_html__('Menu Order', 'ceremony'),
        ),
        'default_option'     => esc_html__('Select Gallery Order By', 'ceremony'),
      ),
      array(
        'id'             => 'gallery_order',
        'type'           => 'select',
        'title'          => esc_html__('Order', 'ceremony'),
        'options'        => array(
          'ASC' => esc_html__('Asending', 'ceremony'),
          'DESC' => esc_html__('Desending', 'ceremony'),
        ),
        'default_option'     => esc_html__('Select Gallery Order', 'ceremony'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Enable/Disable Options', 'ceremony')
      ),
      array(
        'id'      => 'gallery_filter',
        'type'    => 'switcher',
        'title'   => esc_html__('Filter', 'ceremony'),
        'label'   => esc_html__('If you need filter in gallery pages, please turn this ON.', 'ceremony'),
        'default'   => true,
      ),
      array(
        'id'      => 'gallery_pagination',
        'type'    => 'switcher',
        'title'   => esc_html__('Pagination', 'ceremony'),
        'label'   => esc_html__('If you need pagination in gallery pages, please turn this ON.', 'ceremony'),
        'default'   => true,
      ),
      array(
        'id'      => 'gallery_fullwidth',
        'type'    => 'switcher',
        'title'   => esc_html__('Fullwidth', 'ceremony'),
        'label'   => esc_html__('If you need fullwidth layout in gallery pages, please turn this ON.', 'ceremony'),
      ),
      array(
        'id'      => 'gallery_direction_hover',
        'type'    => 'switcher',
        'title'   => esc_html__('Direction Hover', 'ceremony'),
        'label'   => esc_html__('If you need direction hover effect in gallery pages, please turn this ON.', 'ceremony'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Single Gallery', 'ceremony')
      ),
      array(
        'id'      => 'gallery_home_link',
        'type'    => 'text',
        'title'   => esc_html__('Gallery Home Link', 'ceremony'),
        'info'   => esc_html__('Enter link to pagination section grid.', 'ceremony'),
      ),
      array(
        'id'      => 'gallery_single_pagination',
        'type'    => 'switcher',
        'title'   => esc_html__('Next & Prev Navigation', 'ceremony'),
        'label'   => esc_html__('If you don\'t want next and previous navigation in gallery single pages, please turn this OFF.', 'ceremony'),
        'default'   => true,
      ),
      // Gallery Listing

    ),
  );

  // ------------------------------
  // Testimonial Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'testimonial_section',
    'title'    => esc_html__('Testimonial', 'ceremony'),
    'icon'     => 'fa fa-users',
    'fields' => array(

      // Testimonial name change
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Name Change', 'ceremony')
      ),
      array(
        'id'      => 'theme_testimonial_name',
        'type'    => 'text',
        'title'   => esc_html__('Testimonial Name', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => 'Testimonial'
        ),
      ),
      array(
        'id'      => 'theme_testimonial_slug',
        'type'    => 'text',
        'title'   => esc_html__('Testimonial Slug', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => 'testimonial-item'
        ),
      ),
      array(
        'id'      => 'theme_testimonial_cat_slug',
        'type'    => 'text',
        'title'   => esc_html__('Testimonial Category Slug', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => 'testimonial-category'
        ),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'danger',
        'content' => esc_html__('Important: Please do not set testimonial slug and page slug as same. It\'ll not work.', 'ceremony')
      ),
      // Testimonial Name

      // Testimonial Start
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Testimonial Options', 'ceremony')
      ),
      array(
        'id'             => 'testimonial_style',
        'type'           => 'select',
        'title'          => esc_html__('Testimonial Style', 'ceremony'),
        'options'        => array(
          'testimonial_one'          => esc_html__('Style One', 'ceremony'),
          'testimonial_two'          => esc_html__('Style Two', 'ceremony'),
        ),
        'default_option' => esc_html__('Select Testimonial Style', 'ceremony'),
      ),
      array(
        'id'      => 'testi_title',
        'type'    => 'text',
        'title'   => esc_html__('Testimonial Title', 'ceremony'),
        'dependency'     => array('testimonial_style', '==', 'testimonial_one'),
      ),
      array(
        'id'      => 'testimonial_limit',
        'type'    => 'text',
        'title'   => esc_html__('Testimonial Limit', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => '3'
        ),
      ),
      array(
        'id'             => 'testimonial_orderby',
        'type'           => 'select',
        'title'          => esc_html__('Order By', 'ceremony'),
        'options'        => array(
          'none' => esc_html__('None', 'ceremony'),
          'ID' => esc_html__('ID', 'ceremony'),
          'author' => esc_html__('Author', 'ceremony'),
          'title' => esc_html__('Title', 'ceremony'),
          'date' => esc_html__('Date', 'ceremony'),
          'name' => esc_html__('Name', 'ceremony'),
          'modified' => esc_html__('Modified', 'ceremony'),
          'rand' => esc_html__('Random', 'ceremony'),
          'menu_order' => esc_html__('Menu Order', 'ceremony'),
        ),
        'default_option'     => esc_html__('Select Testimonial Order By', 'ceremony'),
      ),
      array(
        'id'             => 'testimonial_order',
        'type'           => 'select',
        'title'          => esc_html__('Order', 'ceremony'),
        'options'        => array(
          'ASC' => esc_html__('Asending', 'ceremony'),
          'DESC' => esc_html__('Desending', 'ceremony'),
        ),
        'default_option'     => esc_html__('Select Testimonial Order', 'ceremony'),
      ),
      // Testimonial End

    ),
  );

  // ------------------------------
  // Friend Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'friends_section',
    'title'    => esc_html__('Friend', 'ceremony'),
    'icon'     => 'fa fa-users',
    'fields' => array(

      // Friend name change
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Name Change', 'ceremony')
      ),
      array(
        'id'      => 'theme_friends_name',
        'type'    => 'text',
        'title'   => esc_html__('Friend Name', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => 'Friend'
        ),
      ),
      array(
        'id'      => 'theme_friends_slug',
        'type'    => 'text',
        'title'   => esc_html__('Friend Slug', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => 'friend-item'
        ),
      ),
      array(
        'id'      => 'theme_friends_cat_slug',
        'type'    => 'text',
        'title'   => esc_html__('Friend Category Slug', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => 'friend-category'
        ),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'danger',
        'content' => esc_html__('Important: Please do not set friend slug and page slug as same. It\'ll not work.', 'ceremony')
      ),
      // Friend Name

      // Friend Start
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Friend Options', 'ceremony')
      ),
      array(
        'id'      => 'friends_limit',
        'type'    => 'text',
        'title'   => esc_html__('Friend Limit', 'ceremony'),
        'attributes'     => array(
          'placeholder'  => '8'
        ),
      ),
      array(
        'id'             => 'friends_orderby',
        'type'           => 'select',
        'title'          => esc_html__('Order By', 'ceremony'),
        'options'        => array(
          'none' => esc_html__('None', 'ceremony'),
          'ID' => esc_html__('ID', 'ceremony'),
          'author' => esc_html__('Author', 'ceremony'),
          'title' => esc_html__('Title', 'ceremony'),
          'date' => esc_html__('Date', 'ceremony'),
          'name' => esc_html__('Name', 'ceremony'),
          'modified' => esc_html__('Modified', 'ceremony'),
          'rand' => esc_html__('Random', 'ceremony'),
          'menu_order' => esc_html__('Menu Order', 'ceremony'),
        ),
        'default_option'     => esc_html__('Select Friend Order By', 'ceremony'),
      ),
      array(
        'id'             => 'friends_order',
        'type'           => 'select',
        'title'          => esc_html__('Order', 'ceremony'),
        'options'        => array(
          'ASC' => esc_html__('Asending', 'ceremony'),
          'DESC' => esc_html__('Desending', 'ceremony'),
        ),
        'default_option'     => esc_html__('Select Friend Order', 'ceremony'),
      ),
      array(
        'id'      => 'friends_show_category',
        'type'    => 'text',
        'title'   => esc_html__('Friend Categorys', 'ceremony'),
        'info'   => esc_html__('Enter category SLUGS (comma separated) you want to display.', 'ceremony'),
      ),
      array(
        'id'    => 'friends_pagination',
        'type'  => 'switcher',
        'title' => esc_html__('Pagination', 'ceremony'),
        'info' => esc_html__('If you need pagination in friend global pages, please turn this ON.', 'ceremony'),
      ),
      array(
        'id'    => 'friends_disable_resize',
        'type'  => 'switcher',
        'title' => esc_html__('Disable Image Resize', 'ceremony'),
        'info' => esc_html__('If you need to disable image resize in friend global pages, please turn this ON.', 'ceremony'),
      ),
      array(
        'id'    => 'friends_direction_hover',
        'type'  => 'switcher',
        'title' => esc_html__('Need Direction Hover', 'ceremony'),
        'info' => esc_html__('If you need direction hover in friend global pages, please turn this ON.', 'ceremony'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Friend Single', 'ceremony')
      ),
      array(
        'id'             => 'friends_single_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Position', 'ceremony'),
        'options'        => array(
          'sidebar-right' => esc_html__('Right', 'ceremony'),
          'sidebar-left' => esc_html__('Left', 'ceremony'),
          'sidebar-hide' => esc_html__('Hide', 'ceremony'),
        ),
        'default_option' => 'Select sidebar position',
        'info'          => esc_html__('Default option : Right', 'ceremony'),
      ),
      array(
        'id'             => 'friends_single_widget',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Widget', 'ceremony'),
        'options'        => ceremony_vt_registered_sidebars(),
        'default_option' => esc_html__('Select Widget', 'ceremony'),
        'dependency'     => array('friends_single_sidebar_position', '!=', 'sidebar-hide'),
        'info'          => esc_html__('Default option : Main Widget Area', 'ceremony'),
      ),
      // Friend End

    ),
  );

  // ------------------------------
  // Blog Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'blog_section',
    'title'    => esc_html__('Blog', 'ceremony'),
    'icon'     => 'fa fa-edit',
    'sections' => array(

      // blog general section
      array(
        'name'     => 'blog_general_tab',
        'title'    => esc_html__('General', 'ceremony'),
        'icon'     => 'fa fa-cog',
        'fields'   => array(

          // Layout
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Layout', 'ceremony')
          ),
          array(
            'id'             => 'blog_listing_style',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Style', 'ceremony'),
            'options'        => array(
              'style-one'   => esc_html__('Style One (List)', 'ceremony'),
              'style-two'   => esc_html__('Style Two (Grid)', 'ceremony'),
            ),
            // 'default_option' => 'Select blog style',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author. If this settings will not apply your blog page, please set that page as a post page in Settings > Readings.', 'ceremony'),
          ),
          array(
            'id'             => 'blog_listing_columns',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Columns', 'ceremony'),
            'options'        => array(
              'col-2' => esc_html__('Column Two', 'ceremony'),
              'col-3' => esc_html__('Column Three', 'ceremony'),
            ),
            'default_option' => 'Select blog column',
            'dependency'     => array('blog_listing_style', '!=', 'style-one'),
          ),
          array(
            'id'    => 'whole_img_link',
            'type'  => 'switcher',
            'title' => esc_html__('Disable Whole Image Link', 'ceremony'),
            'info' => esc_html__('If you don\'t need link for whole featured image, please turn this ON.', 'ceremony'),
          ),
          array(
            'id'             => 'blog_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'ceremony'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'ceremony'),
              'sidebar-left' => esc_html__('Left', 'ceremony'),
              'sidebar-hide' => esc_html__('Hide', 'ceremony'),
            ),
            'default_option' => 'Select sidebar position',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author.', 'ceremony'),
            'info'          => esc_html__('Default option : Right', 'ceremony'),
          ),
          array(
            'id'             => 'blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'ceremony'),
            'options'        => ceremony_vt_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'ceremony'),
            'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'ceremony'),
          ),
          // Layout
          // Global Options
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Global Options', 'ceremony')
          ),
          array(
            'id'         => 'theme_exclude_categories',
            'type'       => 'checkbox',
            'title'      => esc_html__('Exclude Categories', 'ceremony'),
            'info'      => esc_html__('Select categories you want to exclude from blog page.', 'ceremony'),
            'options'    => 'categories',
          ),
          array(
            'id'      => 'theme_blog_home',
            'type'    => 'text',
            'title'   => esc_html__('Blog Home Page Link', 'ceremony'),
            'info'   => esc_html__('Enter blog home page link here.', 'ceremony'),
          ),
          array(
            'id'      => 'theme_blog_excerpt',
            'type'    => 'text',
            'title'   => esc_html__('Excerpt Length', 'ceremony'),
            'info'   => esc_html__('Blog short content length, in blog listing pages.', 'ceremony'),
            'default' => '35',
          ),
          array(
            'id'      => 'blog_pagination_style',
            'type'    => 'select',
            'title'   => esc_html__('Blog Pagination', 'ceremony'),
            'options'        => array(
              'navigation' => esc_html__('Navigation', 'ceremony'),
              'load-more' => esc_html__('Ajax Button', 'ceremony'),
              'infinite-scroll' => esc_html__('Ajax Infinite Scroll', 'ceremony'),
            ),
            'info'          => esc_html__('Default : Navigation', 'ceremony'),
          ),
          array(
            'id'      => 'blog_load_more_btn_txt',
            'type'    => 'text',
            'title'   => esc_html__('Load More Button Text', 'ceremony'),
            'dependency'     => array('blog_pagination_style', '==', 'load-more'),
          ),
          array(
            'id'      => 'theme_metas_hide',
            'type'    => 'checkbox',
            'title'   => esc_html__('Meta\'s to hide', 'ceremony'),
            'info'    => esc_html__('Check items you want to hide from blog/post meta field.', 'ceremony'),
            'class'      => 'horizontal',
            'options'    => array(
              'category'   => esc_html__('Category', 'ceremony'),
              'date'    => esc_html__('Date', 'ceremony'),
              'author'     => esc_html__('Author', 'ceremony'),
              'comments'      => esc_html__('Comments', 'ceremony'),
            ),
            // 'default' => '30',
          ),
          array(
            "id"  => "blog_date_format",
            "type"        => 'text',
            "title"     => esc_html__('Date Format', 'ceremony'),
            "info" => esc_html__( "Enter date format (for more info <a href='https://codex.wordpress.org/Formatting_Date_and_Time' target='_blank'>click here</a>).", 'ceremony')
          ),
          // End fields

        )
      ),

      // blog single section
      array(
        'name'     => 'blog_single_tab',
        'title'    => esc_html__('Single', 'ceremony'),
        'icon'     => 'fa fa-sticky-note',
        'fields'   => array(

          // Start fields
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Enable / Disable', 'ceremony')
          ),
          array(
            'id'    => 'single_featured_image',
            'type'  => 'switcher',
            'title' => esc_html__('Featured Image', 'ceremony'),
            'info' => esc_html__('If need to hide featured image from single blog post page, please turn this OFF.', 'ceremony'),
            'default' => true,
          ),
          array(
            'id'    => 'single_tag_list',
            'type'  => 'switcher',
            'title' => esc_html__('Tags', 'ceremony'),
            'info' => esc_html__('If need to hide tags from single blog post page, please turn this OFF.', 'ceremony'),
            'default' => true,
          ),
          array(
            'id'    => 'single_category_list',
            'type'  => 'switcher',
            'title' => esc_html__('Category', 'ceremony'),
            'info' => esc_html__('If need to hide category from single blog post page, please turn this OFF.', 'ceremony'),
            'default' => true,
          ),
          array(
            'id'    => 'single_share_option',
            'type'  => 'switcher',
            'title' => esc_html__('Share Option', 'ceremony'),
            'info' => esc_html__('If need to hide share option on single blog page, please turn this OFF.', 'ceremony'),
            'default' => true,
          ),
          array(
            'id'    => 'single_author_info',
            'type'  => 'switcher',
            'title' => esc_html__('Author Info', 'ceremony'),
            'info' => esc_html__('If need to hide author info on single blog page, please turn this OFF.', 'ceremony'),
            'default' => true,
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Sidebar', 'ceremony')
          ),
          array(
            'id'             => 'single_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'ceremony'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'ceremony'),
              'sidebar-left' => esc_html__('Left', 'ceremony'),
              'sidebar-hide' => esc_html__('Hide', 'ceremony'),
            ),
            'default_option' => 'Select sidebar position',
            'info'          => esc_html__('Default option : Right', 'ceremony'),
          ),
          array(
            'id'             => 'single_blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'ceremony'),
            'options'        => ceremony_vt_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'ceremony'),
            'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'ceremony'),
          ),
          // End fields

        )
      ),

    ),
  );

// ------------------------------
  // Event Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'event_section',
    'title'    => esc_html__('Event', 'ceremony'),
    'icon'     => 'fa fa-edit',
    'fields'   => array(
        // Global Options
        array(
          'type'    => 'notice',
          'class'   => 'info cs-vt-heading',
          'content' => esc_html__('Global Options', 'ceremony')
        ),
        array(
          'id'        => 'event_styles',
          'type'      => 'select',
          'title'     => esc_html__('Choose Event STyle', 'ceremony'),
          'options'   => array(
            'default'    => esc_html__( 'Default', 'ceremony' ),
            'style_one'    => esc_html__( 'Style One', 'ceremony' ),
          ),
        ),
        array(
          'id'    => 'event_pagination',
          'type'  => 'switcher',
          'title' => esc_html__('Pagination', 'ceremony'),
          'info' => esc_html__('If need to hide pagination on event(list) page, please turn this OFF.', 'ceremony'),
          'default' => true,
        ),
        array(
          "id"  => "event_date_format",
          "type"        => 'text',
          "title"     => esc_html__('Date Format', 'ceremony'),
          "info" => esc_html__( "Enter date format (for more info <a href='https://codex.wordpress.org/Formatting_Date_and_Time' target='_blank'>click here</a>).", 'ceremony')
        ),
        // End fields

    ),

  );

if (class_exists( 'WooCommerce' )){
  // ------------------------------
  // WooCommerce Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'woocommerce_section',
    'title'    => esc_html__('WooCommerce', 'ceremony'),
    'icon'     => 'fa fa-shopping-cart',
    'fields' => array(

      // Start fields
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Layout', 'ceremony')
      ),
      array(
        'id'             => 'woo_product_columns',
        'type'           => 'select',
        'title'          => esc_html__('Product Column', 'ceremony'),
        'options'        => array(
          3 => esc_html__('Three Column', 'ceremony'),
          4 => esc_html__('Four Column', 'ceremony'),
        ),
        'default_option' => esc_html__('Select Product Columns', 'ceremony'),
        'help'          => esc_html__('This style will apply, default woocommerce listings pages. Like, shop and archive pages.', 'ceremony'),
      ),
      array(
        'id'             => 'woo_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Position', 'ceremony'),
        'options'        => array(
          'right-sidebar' => esc_html__('Right', 'ceremony'),
          'left-sidebar' => esc_html__('Left', 'ceremony'),
          'sidebar-hide' => esc_html__('Hide', 'ceremony'),
        ),
        'default_option' => esc_html__('Select sidebar position', 'ceremony'),
        'info'          => esc_html__('Default option : Right', 'ceremony'),
      ),
      array(
        'id'             => 'woo_widget',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Widget', 'ceremony'),
        'options'        => ceremony_vt_registered_sidebars(),
        'default_option' => esc_html__('Select Widget', 'ceremony'),
        'dependency'     => array('woo_sidebar_position', '!=', 'sidebar-hide'),
        'info'          => esc_html__('Select woocommerce page widget', 'ceremony'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Listing', 'ceremony')
      ),
      array(
        'id'      => 'theme_woo_limit',
        'type'    => 'text',
        'title'   => esc_html__('Product Limit', 'ceremony'),
        'info'   => esc_html__('Enter the number value for per page products limit.', 'ceremony'),
      ),
      array(
        'id'               => 'woo_hover_image',
        'type'             => 'switcher',
        'title'            => esc_html__('Image Change Hover Effect', 'ceremony'),
        'info'             => esc_html__('If you don\'t want \'image change animation on hover\' on each product, please turn this OFF.', 'ceremony'),
        'default'          => true,
      ),
      // End fields

      // Start fields
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Single Product', 'ceremony')
      ),
      array(
        'id'             => 'woo_related_limit',
        'type'           => 'text',
        'title'          => esc_html__('Related Products Limit', 'ceremony'),
      ),
      array(
        'id'             => 'woo_related_title',
        'type'           => 'text',
        'title'          => esc_html__('Related Products Title', 'ceremony'),
      ),
      array(
        'id'             => 'woo_related_sub_title',
        'type'           => 'text',
        'title'          => esc_html__('Related Products Sub-Title', 'ceremony'),
      ),
      array(
        'id'    => 'woo_hide_zoom',
        'type'  => 'switcher',
        'title' => esc_html__('Disable Zoom Image', 'ceremony'),
        'info' => esc_html__('If you don\'t want \'Zoom image option\' in single product page, please turn this ON.', 'ceremony'),
        'default' => false,
      ),
      array(
        'id'    => 'woo_single_upsell',
        'type'  => 'switcher',
        'title' => esc_html__('You May Also Like(Upsell)', 'ceremony'),
        'info' => esc_html__('If you want \'You May Also Like\' products in single product page, please turn this ON.', 'ceremony'),
        'default' => false,
      ),
      array(
        'id'             => 'up_sell_column',
        'type'           => 'select',
        'title'          => esc_html__('Up-Sell Products Column', 'ceremony'),
        'options'        => array(
          3 => esc_html__('Three Column', 'ceremony'),
          4 => esc_html__('Four Column', 'ceremony'),
        ),
        'default_option' => esc_html__('Select Product Columns', 'ceremony'),
        'dependency'     => array('woo_single_upsell', '==', 'true'),
      ),
      array(
        'id'    => 'woo_single_crosssell',
        'type'  => 'switcher',
        'title' => esc_html__('You May interested in(Cross Sell)', 'ceremony'),
        'info' => esc_html__('If you want \'You May interested in\' products in cart page, please turn this ON.', 'ceremony'),
        'default' => false,
      ),
      array(
        'id'    => 'woo_single_related',
        'type'  => 'switcher',
        'title' => esc_html__('Related Products', 'ceremony'),
        'info' => esc_html__('If you want \'Related Products\' in single product page, please turn this ON.', 'ceremony'),
        'default' => false,
      ),
      // End fields

    ),
  );
}

  // ------------------------------
  // Extra Pages
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_extra_pages',
    'title'    => esc_html__('Extra Pages', 'ceremony'),
    'icon'     => 'fa fa-clone',
    'sections' => array(

      // error 404 page
      array(
        'name'     => 'error_page_section',
        'title'    => esc_html__('404 Page', 'ceremony'),
        'icon'     => 'fa fa-exclamation-triangle',
        'fields'   => array(

          // Start 404 Page
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('404 Error Page Options', 'ceremony')
          ),
          array(
            'id'    => 'error_title',
            'type'  => 'text',
            'title' => esc_html__('404 Text', 'ceremony'),
            'info'  => esc_html__('Enter 404 text here.', 'ceremony'),
          ),
          array(
            'id'    => 'error_heading',
            'type'  => 'text',
            'title' => esc_html__('404 Page Heading', 'ceremony'),
            'info'  => esc_html__('Enter 404 page heading.', 'ceremony'),
          ),
          array(
            'id'    => 'error_page_content',
            'type'  => 'textarea',
            'title' => esc_html__('404 Page Content', 'ceremony'),
            'info'  => esc_html__('Enter 404 page content.', 'ceremony'),
            'shortcode' => true,
          ),
          array(
            'id'    => 'error_page_bg',
            'type'  => 'image',
            'title' => esc_html__('404 Page Background', 'ceremony'),
            'info'  => esc_html__('Choose 404 page background styles.', 'ceremony'),
            'add_title' => esc_html__('Add 404 Image', 'ceremony'),
          ),
          array(
            'id'    => 'error_btn_text',
            'type'  => 'text',
            'title' => esc_html__('Button Text', 'ceremony'),
            'info'  => esc_html__('Enter BACK TO HOME button text. If you want to change it.', 'ceremony'),
          ),
          // End 404 Page

        ) // end: fields
      ), // end: fields section

      // maintenance mode page
      array(
        'name'     => 'maintenance_mode_section',
        'title'    => esc_html__('Maintenance Mode', 'ceremony'),
        'icon'     => 'fa fa-hourglass-half',
        'fields'   => array(

          // Start Maintenance Mode
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('If you turn this ON : Only Logged in users will see your pages. All other visiters will see, selected page of : Maintenance Mode Page', 'ceremony')
          ),
          array(
            'id'             => 'enable_maintenance_mode',
            'type'           => 'switcher',
            'title'          => esc_html__('Maintenance Mode', 'ceremony'),
            'default'        => false,
          ),
          array(
            'id'             => 'maintenance_mode_page',
            'type'           => 'select',
            'title'          => esc_html__('Maintenance Mode Page', 'ceremony'),
            'options'        => 'pages',
            'default_option' => esc_html__('Select a page', 'ceremony'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          // End Maintenance Mode

        ) // end: fields
      ), // end: fields section

    )
  );

  // ------------------------------
  // Advanced
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_advanced',
    'title'  => esc_html__('Advanced', 'ceremony'),
    'icon'   => 'fa fa-cog'
  );

  // ------------------------------
  // Misc Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'misc_section',
    'title'    => esc_html__('Misc', 'ceremony'),
    'icon'     => 'fa fa-recycle',
    'sections' => array(

      // custom sidebar section
      array(
        'name'     => 'custom_sidebar_section',
        'title'    => esc_html__('Custom Sidebar', 'ceremony'),
        'icon'     => 'fa fa-reorder',
        'fields'   => array(

          // start fields
          array(
            'id'              => 'custom_sidebar',
            'title'           => esc_html__('Sidebars', 'ceremony'),
            'desc'            => esc_html__('Go to Appearance -> Widgets after create sidebars', 'ceremony'),
            'type'            => 'group',
            'fields'          => array(
              array(
                'id'          => 'sidebar_name',
                'type'        => 'text',
                'title'       => esc_html__('Sidebar Name', 'ceremony'),
              ),
              array(
                'id'          => 'sidebar_desc',
                'type'        => 'text',
                'title'       => esc_html__('Custom Description', 'ceremony'),
              )
            ),
            'accordion'       => true,
            'button_title'    => esc_html__('Add New Sidebar', 'ceremony'),
            'accordion_title' => esc_html__('New Sidebar', 'ceremony'),
          ),
          // end fields
        )
      ),
      // custom sidebar section

      // Translation
      array(
        'name'        => 'theme_translation_section',
        'title'       => esc_html__('Translation', 'ceremony'),
        'icon'        => 'fa fa-language',

        // begin: fields
        'fields'      => array(
          // Start Translation
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Common Texts', 'ceremony')
          ),
          array(
            'id'          => 'read_more_text',
            'type'        => 'text',
            'title'       => esc_html__('Read More Text', 'ceremony'),
          ),
          array(
            'id'          => 'share_text',
            'type'        => 'text',
            'title'       => esc_html__('Share Text', 'ceremony'),
          ),
          array(
            'id'          => 'share_on_text',
            'type'        => 'text',
            'title'       => esc_html__('Share On Tooltip Text', 'ceremony'),
          ),
          array(
            'id'          => 'author_text',
            'type'        => 'text',
            'title'       => esc_html__('Author Text', 'ceremony'),
          ),
          array(
            'id'          => 'author_by_text',
            'type'        => 'text',
            'title'       => esc_html__('Author (By) Text', 'ceremony'),
          ),
          array(
            'id'          => 'post_comment_text',
            'type'        => 'text',
            'title'       => esc_html__('Post Comment Text [Submit Button]', 'ceremony'),
          ),
          array(
            'id'          => 'gallery_details_text',
            'type'        => 'text',
            'title'       => esc_html__('Gallery Details Text', 'ceremony'),
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Gallery Filter', 'ceremony')
          ),
          array(
            'id'          => 'all_text',
            'type'        => 'text',
            'title'       => esc_html__('All Text', 'ceremony'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Single Post Pagination', 'ceremony'),
          ),
          array(
            'id'          => 'older_post',
            'type'        => 'text',
            'title'       => esc_html__('Older Posts Text', 'ceremony'),
          ),
          array(
            'id'          => 'newer_post',
            'type'        => 'text',
            'title'       => esc_html__('Newer Posts Text', 'ceremony'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Single Gallery Pagination', 'ceremony')
          ),
          array(
            'id'          => 'prev_gallery',
            'type'        => 'text',
            'title'       => esc_html__('Previour Gallery Text', 'ceremony'),
          ),
          array(
            'id'          => 'next_gallery',
            'type'        => 'text',
            'title'       => esc_html__('Next Gallery Text', 'ceremony'),
          ),
          // End Translation
        ) // end: fields
      ),

    ),
  );


  // ------------------------------
  // backup                       -
  // ------------------------------
  $options[]   = array(
    'name'     => 'backup_section',
    'title'    => 'Backup',
    'icon'     => 'fa fa-shield',
    'fields'   => array(

      array(
        'type'    => 'notice',
        'class'   => 'warning',
        'content' => 'You can save your current options. Download a Backup and Import.',
      ),
      array(
        'type'    => 'backup',
      ),

    )
  );
  return $options;
}
add_filter( 'cs_framework_options', 'ceremony_vt_options' );
